# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: picture.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpicture.proto\x12\nbatchx.cdn\x1a\x0c\x63ommon.proto\"\xdc\x01\n\x12\x43ropPictureRequest\x12\x13\n\x0bpicture_key\x18\x01 \x01(\t\x12-\n\x0cpicture_type\x18\x02 \x01(\x0e\x32\x17.batchx.cdn.PictureType\x12\x31\n\x04\x63rop\x18\x03 \x01(\x0b\x32#.batchx.cdn.CropPictureRequest.Crop\x1aO\n\x04\x43rop\x12%\n\x06region\x18\x01 \x01(\x0b\x32\x15.batchx.common.Region\x12 \n\x18keep_uncropped_thumbnail\x18\x02 \x01(\x08\">\n\x13\x43ropPictureResponse\x12\'\n\x07picture\x18\x01 \x01(\x0b\x32\x16.batchx.common.Picture\"9\n\rUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0b\x66ile_length\x18\x02 \x01(\x03\"\x84\x02\n\x0eUploadResponse\x12\x43\n\x10upload_post_data\x18\x01 \x01(\x0b\x32).batchx.cdn.UploadResponse.UploadPostData\x1a\xac\x01\n\x0eUploadPostData\x12\x10\n\x08post_url\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12J\n\tpost_data\x18\x03 \x03(\x0b\x32\x37.batchx.cdn.UploadResponse.UploadPostData.PostDataEntry\x1a/\n\rPostDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x15\x43ompleteUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x12\n\nupload_key\x18\x02 \x01(\t\x12-\n\x0cpicture_type\x18\x03 \x01(\x0e\x32\x17.batchx.cdn.PictureType\x12\x34\n\x04\x63rop\x18\x04 \x01(\x0b\x32&.batchx.cdn.CompleteUploadRequest.Crop\x1aO\n\x04\x43rop\x12%\n\x06region\x18\x01 \x01(\x0b\x32\x15.batchx.common.Region\x12 \n\x18keep_uncropped_thumbnail\x18\x02 \x01(\x08\"A\n\x16\x43ompleteUploadResponse\x12\'\n\x07picture\x18\x01 \x01(\x0b\x32\x16.batchx.common.Picture*@\n\x0bPictureType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\n\n\x06\x41VATAR\x10\x02\x12\r\n\tTHUMBNAIL\x10\x03\x32\x97\x02\n\x0ePictureService\x12\x44\n\x06Upload\x12\x19.batchx.cdn.UploadRequest\x1a\x1a.batchx.cdn.UploadResponse\"\x03\x90\x02\x01\x12\\\n\x0e\x43ompleteUpload\x12!.batchx.cdn.CompleteUploadRequest\x1a\".batchx.cdn.CompleteUploadResponse\"\x03\x90\x02\x02\x12S\n\x0b\x43ropPicture\x12\x1e.batchx.cdn.CropPictureRequest\x1a\x1f.batchx.cdn.CropPictureResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x02\x42\x1f\n\x0fio.batchx.protoB\x0cPictureProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'picture_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014PictureProto'
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._options = None
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_options = b'8\001'
  _PICTURESERVICE._options = None
  _PICTURESERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\002'
  _PICTURESERVICE.methods_by_name['Upload']._options = None
  _PICTURESERVICE.methods_by_name['Upload']._serialized_options = b'\220\002\001'
  _PICTURESERVICE.methods_by_name['CompleteUpload']._options = None
  _PICTURESERVICE.methods_by_name['CompleteUpload']._serialized_options = b'\220\002\002'
  _PICTURESERVICE.methods_by_name['CropPicture']._options = None
  _PICTURESERVICE.methods_by_name['CropPicture']._serialized_options = b'\220\002\002'
  _PICTURETYPE._serialized_start=968
  _PICTURETYPE._serialized_end=1032
  _CROPPICTUREREQUEST._serialized_start=44
  _CROPPICTUREREQUEST._serialized_end=264
  _CROPPICTUREREQUEST_CROP._serialized_start=185
  _CROPPICTUREREQUEST_CROP._serialized_end=264
  _CROPPICTURERESPONSE._serialized_start=266
  _CROPPICTURERESPONSE._serialized_end=328
  _UPLOADREQUEST._serialized_start=330
  _UPLOADREQUEST._serialized_end=387
  _UPLOADRESPONSE._serialized_start=390
  _UPLOADRESPONSE._serialized_end=650
  _UPLOADRESPONSE_UPLOADPOSTDATA._serialized_start=478
  _UPLOADRESPONSE_UPLOADPOSTDATA._serialized_end=650
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_start=603
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_end=650
  _COMPLETEUPLOADREQUEST._serialized_start=653
  _COMPLETEUPLOADREQUEST._serialized_end=899
  _COMPLETEUPLOADREQUEST_CROP._serialized_start=185
  _COMPLETEUPLOADREQUEST_CROP._serialized_end=264
  _COMPLETEUPLOADRESPONSE._serialized_start=901
  _COMPLETEUPLOADRESPONSE._serialized_end=966
  _PICTURESERVICE._serialized_start=1035
  _PICTURESERVICE._serialized_end=1314
# @@protoc_insertion_point(module_scope)
