# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x0c\x62\x61tchx.admin\x1a\x0c\x63ommon.proto\"\xc4\x01\n\x18GeneratePromoCodeRequest\x12?\n\x07\x63redits\x18\x01 \x01(\x0e\x32..batchx.admin.GeneratePromoCodeRequest.Credits\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0eusages_allowed\x18\x03 \x01(\x05\x12\x13\n\x0b\x64istributor\x18\x04 \x01(\t\"%\n\x07\x43redits\x12\x07\n\x03\x43\x32\x35\x10\x00\x12\x07\n\x03\x43\x35\x30\x10\x01\x12\x08\n\x04\x43\x31\x30\x30\x10\x02\"/\n\x19GeneratePromoCodeResponse\x12\x12\n\npromo_code\x18\x01 \x01(\t\"\x1f\n\x11RemoveUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x14\n\x12RemoveUserResponse\"\x1c\n\x1aGetGlobalPropertiesRequest\"K\n\x1bGetGlobalPropertiesResponse\x12,\n\nassignment\x18\x01 \x03(\x0b\x32\x18.batchx.admin.Assignment\"K\n\nAssignment\x12.\n\x08property\x18\x01 \x01(\x0e\x32\x1c.batchx.admin.GlobalProperty\x12\r\n\x05value\x18\x02 \x01(\t\"H\n\x18SetGlobalPropertyRequest\x12,\n\nassignment\x18\x01 \x01(\x0b\x32\x18.batchx.admin.Assignment\"\x1b\n\x19SetGlobalPropertyResponse\"T\n\x1c\x41\x64\x64\x45nvironmentCreditsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07\x63redits\x18\x02 \x01(\x03\x12\x0e\n\x06reason\x18\x03 \x01(\t\"\x1f\n\x1d\x41\x64\x64\x45nvironmentCreditsResponse\"]\n\x10\x43reateOrgRequest\x12-\n\x08org_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\"\x8b\x02\n\x11\x43reateUserRequest\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\x12\x42\n\nmembership\x18\x03 \x03(\x0b\x32..batchx.admin.CreateUserRequest.MembershipData\x1an\n\x0eMembershipData\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x43\n\x04type\x18\x02 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\"\xbb\x01\n\x17\x43reateMembershipRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x45\n\x04type\x18\x03 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipTypeH\x00\x12\x10\n\x06remove\x18\x04 \x01(\x08H\x00\x42\x1d\n\x1b\x43reateMembershipRequestType\"\x1a\n\x18\x43reateMembershipResponse\"\x14\n\x12\x43reateUserResponse\"\x13\n\x11\x43reateOrgResponse*[\n\x0eGlobalProperty\x12 \n\x1c\x42OOLEAN_DISABLE_RATE_LIMITER\x10\x00\x12\'\n#BOOLEAN_DISABLE_CONCURRENCE_LIMITER\x10\x01\x32\xa5\x06\n\x0c\x41\x64minService\x12T\n\nCreateUser\x12\x1f.batchx.admin.CreateUserRequest\x1a .batchx.admin.CreateUserResponse\"\x03\x90\x02\x02\x12T\n\nRemoveUser\x12\x1f.batchx.admin.RemoveUserRequest\x1a .batchx.admin.RemoveUserResponse\"\x03\x90\x02\x02\x12Q\n\tCreateOrg\x12\x1e.batchx.admin.CreateOrgRequest\x1a\x1f.batchx.admin.CreateOrgResponse\"\x03\x90\x02\x02\x12\x66\n\x10\x43reateMembership\x12%.batchx.admin.CreateMembershipRequest\x1a&.batchx.admin.CreateMembershipResponse\"\x03\x90\x02\x02\x12r\n\x15\x41\x64\x64\x45nvironmentCredits\x12*.batchx.admin.AddEnvironmentCreditsRequest\x1a+.batchx.admin.AddEnvironmentCreditsResponse\"\x00\x12\x66\n\x11SetGlobalProperty\x12&.batchx.admin.SetGlobalPropertyRequest\x1a\'.batchx.admin.SetGlobalPropertyResponse\"\x00\x12l\n\x13GetGlobalProperties\x12(.batchx.admin.GetGlobalPropertiesRequest\x1a).batchx.admin.GetGlobalPropertiesResponse\"\x00\x12\x64\n\x11GeneratePromoCode\x12&.batchx.admin.GeneratePromoCodeRequest\x1a\'.batchx.admin.GeneratePromoCodeResponseB\x1d\n\x0fio.batchx.protoB\nAdminProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nAdminProto'
  _ADMINSERVICE.methods_by_name['CreateUser']._options = None
  _ADMINSERVICE.methods_by_name['CreateUser']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['RemoveUser']._options = None
  _ADMINSERVICE.methods_by_name['RemoveUser']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['CreateOrg']._options = None
  _ADMINSERVICE.methods_by_name['CreateOrg']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['CreateMembership']._options = None
  _ADMINSERVICE.methods_by_name['CreateMembership']._serialized_options = b'\220\002\002'
  _GLOBALPROPERTY._serialized_start=1378
  _GLOBALPROPERTY._serialized_end=1469
  _GENERATEPROMOCODEREQUEST._serialized_start=44
  _GENERATEPROMOCODEREQUEST._serialized_end=240
  _GENERATEPROMOCODEREQUEST_CREDITS._serialized_start=203
  _GENERATEPROMOCODEREQUEST_CREDITS._serialized_end=240
  _GENERATEPROMOCODERESPONSE._serialized_start=242
  _GENERATEPROMOCODERESPONSE._serialized_end=289
  _REMOVEUSERREQUEST._serialized_start=291
  _REMOVEUSERREQUEST._serialized_end=322
  _REMOVEUSERRESPONSE._serialized_start=324
  _REMOVEUSERRESPONSE._serialized_end=344
  _GETGLOBALPROPERTIESREQUEST._serialized_start=346
  _GETGLOBALPROPERTIESREQUEST._serialized_end=374
  _GETGLOBALPROPERTIESRESPONSE._serialized_start=376
  _GETGLOBALPROPERTIESRESPONSE._serialized_end=451
  _ASSIGNMENT._serialized_start=453
  _ASSIGNMENT._serialized_end=528
  _SETGLOBALPROPERTYREQUEST._serialized_start=530
  _SETGLOBALPROPERTYREQUEST._serialized_end=602
  _SETGLOBALPROPERTYRESPONSE._serialized_start=604
  _SETGLOBALPROPERTYRESPONSE._serialized_end=631
  _ADDENVIRONMENTCREDITSREQUEST._serialized_start=633
  _ADDENVIRONMENTCREDITSREQUEST._serialized_end=717
  _ADDENVIRONMENTCREDITSRESPONSE._serialized_start=719
  _ADDENVIRONMENTCREDITSRESPONSE._serialized_end=750
  _CREATEORGREQUEST._serialized_start=752
  _CREATEORGREQUEST._serialized_end=845
  _CREATEUSERREQUEST._serialized_start=848
  _CREATEUSERREQUEST._serialized_end=1115
  _CREATEUSERREQUEST_MEMBERSHIPDATA._serialized_start=1005
  _CREATEUSERREQUEST_MEMBERSHIPDATA._serialized_end=1115
  _CREATEMEMBERSHIPREQUEST._serialized_start=1118
  _CREATEMEMBERSHIPREQUEST._serialized_end=1305
  _CREATEMEMBERSHIPRESPONSE._serialized_start=1307
  _CREATEMEMBERSHIPRESPONSE._serialized_end=1333
  _CREATEUSERRESPONSE._serialized_start=1335
  _CREATEUSERRESPONSE._serialized_end=1355
  _CREATEORGRESPONSE._serialized_start=1357
  _CREATEORGRESPONSE._serialized_end=1376
  _ADMINSERVICE._serialized_start=1472
  _ADMINSERVICE._serialized_end=2277
# @@protoc_insertion_point(module_scope)
