# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: billing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rbilling.proto\x12\x0e\x62\x61tchx.billing\x1a\x0c\x63ommon.proto\"2\n\x1a\x43reatePaymentIntentRequest\x12\x14\n\x0c\x61mount_cents\x18\x01 \x01(\x05\"4\n\x1b\x43reatePaymentIntentResponse\x12\x15\n\rclient_secret\x18\x01 \x01(\t2\x93\x01\n\x0e\x42illingService\x12s\n\x13\x43reatePaymentIntent\x12*.batchx.billing.CreatePaymentIntentRequest\x1a+.batchx.billing.CreatePaymentIntentResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42\x1f\n\x0fio.batchx.protoB\x0c\x42illingProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'billing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014BillingProto'
  _BILLINGSERVICE._options = None
  _BILLINGSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _BILLINGSERVICE.methods_by_name['CreatePaymentIntent']._options = None
  _BILLINGSERVICE.methods_by_name['CreatePaymentIntent']._serialized_options = b'\220\002\001'
  _CREATEPAYMENTINTENTREQUEST._serialized_start=47
  _CREATEPAYMENTINTENTREQUEST._serialized_end=97
  _CREATEPAYMENTINTENTRESPONSE._serialized_start=99
  _CREATEPAYMENTINTENTRESPONSE._serialized_end=151
  _BILLINGSERVICE._serialized_start=154
  _BILLINGSERVICE._serialized_end=301
# @@protoc_insertion_point(module_scope)
