# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import user_pb2 as user__pb2
from . import organization_pb2 as organization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x65nvironment.proto\x12\x12\x62\x61tchx.environment\x1a\x0c\x63ommon.proto\x1a\nuser.proto\x1a\x12organization.proto\"\"\n\x14IsIdAvailableRequest\x12\n\n\x02id\x18\x01 \x01(\t\"*\n\x15IsIdAvailableResponse\x12\x11\n\tavailable\x18\x01 \x01(\x08\"\x14\n\x12ListRegionsRequest\")\n\x06Region\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"A\n\x13ListRegionsResponse\x12*\n\x06region\x18\x01 \x03(\x0b\x32\x1a.batchx.environment.Region\",\n\x15GetEnvironmentRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\"\xf8\x04\n\x16GetEnvironmentResponse\x12N\n\rinternal_data\x18\x01 \x01(\x0b\x32\x37.batchx.environment.GetEnvironmentResponse.InternalData\x12\x35\n\ruser_response\x18\x02 \x01(\x0b\x32\x1c.batchx.user.GetUserResponseH\x00\x12M\n\x15organization_response\x18\x03 \x01(\x0b\x32,.batchx.organization.GetOrganizationResponseH\x00\x1a\xff\x02\n\x0cInternalData\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x15\n\rstorage_quota\x18\x02 \x01(\x03\x12\x17\n\x0fstorage_current\x18\x03 \x01(\x03\x12\x19\n\x11\x63omputing_credits\x18\x04 \x01(\x03\x12\x1e\n\x16ts_credits_consumption\x18\x05 \x01(\x03\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x17\n\x0forganization_id\x18\x07 \x01(\t\x12(\n max_credits_consumption_per_hour\x18\x08 \x01(\x03\x12\x1c\n\x14\x63onsumption_per_hour\x18\t \x01(\x03\x12\x18\n\x10max_used_storage\x18\n \x01(\x03\x12\r\n\x05\x66s_v3\x18\x0b \x01(\x08\x12\x12\n\naudit_logs\x18\x0c \x01(\x08\x12\x1f\n\x17\x61rchive_storage_current\x18\r \x01(\x03\x12 \n\x18max_used_archive_storage\x18\x0e \x01(\x03\x42\x06\n\x04Type2\xe0\x02\n\x12\x45nvironmentService\x12l\n\x0eGetEnvironment\x12).batchx.environment.GetEnvironmentRequest\x1a*.batchx.environment.GetEnvironmentResponse\"\x03\x90\x02\x01\x12\x63\n\x0bListRegions\x12&.batchx.environment.ListRegionsRequest\x1a\'.batchx.environment.ListRegionsResponse\"\x03\x90\x02\x01\x12i\n\rIsIdAvailable\x12(.batchx.environment.IsIdAvailableRequest\x1a).batchx.environment.IsIdAvailableResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42#\n\x0fio.batchx.protoB\x10\x45nvironmentProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'environment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\020EnvironmentProto'
  _ENVIRONMENTSERVICE._options = None
  _ENVIRONMENTSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _ENVIRONMENTSERVICE.methods_by_name['GetEnvironment']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['GetEnvironment']._serialized_options = b'\220\002\001'
  _ENVIRONMENTSERVICE.methods_by_name['ListRegions']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['ListRegions']._serialized_options = b'\220\002\001'
  _ENVIRONMENTSERVICE.methods_by_name['IsIdAvailable']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['IsIdAvailable']._serialized_options = b'\220\002\001'
  _ISIDAVAILABLEREQUEST._serialized_start=87
  _ISIDAVAILABLEREQUEST._serialized_end=121
  _ISIDAVAILABLERESPONSE._serialized_start=123
  _ISIDAVAILABLERESPONSE._serialized_end=165
  _LISTREGIONSREQUEST._serialized_start=167
  _LISTREGIONSREQUEST._serialized_end=187
  _REGION._serialized_start=189
  _REGION._serialized_end=230
  _LISTREGIONSRESPONSE._serialized_start=232
  _LISTREGIONSRESPONSE._serialized_end=297
  _GETENVIRONMENTREQUEST._serialized_start=299
  _GETENVIRONMENTREQUEST._serialized_end=343
  _GETENVIRONMENTRESPONSE._serialized_start=346
  _GETENVIRONMENTRESPONSE._serialized_end=978
  _GETENVIRONMENTRESPONSE_INTERNALDATA._serialized_start=587
  _GETENVIRONMENTRESPONSE_INTERNALDATA._serialized_end=970
  _ENVIRONMENTSERVICE._serialized_start=981
  _ENVIRONMENTSERVICE._serialized_end=1333
# @@protoc_insertion_point(module_scope)
