# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x0b\x62\x61tchx.auth\x1a\x0c\x63ommon.proto\"#\n\x12StartSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\x15\n\x13StartSignupResponse\"\'\n\x13GoogleSigninRequest\x12\x10\n\x08id_token\x18\x01 \x01(\t\"J\n\x14GoogleSigninResponse\x12\x32\n\x0etoken_response\x18\x01 \x01(\x0b\x32\x1a.batchx.auth.TokenResponse\"p\n\x13GoogleSignupRequest\x12\x10\n\x08id_token\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x15\n\rcaptcha_token\x18\x04 \x01(\t\x12\x12\n\npromo_code\x18\x05 \x01(\t\"\x16\n\x14GoogleSignupResponse\"\xa0\x01\n\rSignupRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x15\n\rcaptcha_token\x18\x07 \x01(\t\x12\x12\n\npromo_code\x18\x08 \x01(\t\"\x10\n\x0eSignupResponse\"?\n\x14\x43onfirmSignupRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x02 \x01(\t\"\x17\n\x15\x43onfirmSignupResponse\"3\n#ResendSignupConfirmationCodeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n$ResendSignupConfirmationCodeResponse\"?\n\x13RefreshTokenRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\",\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"E\n\x19RevokeRefreshTokenRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"\x1c\n\x1aRevokeRefreshTokenResponse\"\xea\x01\n\x0cLoginRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x12\n\x08password\x18\x02 \x01(\tH\x00\x12I\n\x12\x63hallenge_response\x18\x03 \x01(\x0b\x32+.batchx.auth.LoginRequest.ChallengeResponseH\x00\x1a`\n\x11\x43hallengeResponse\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.batchx.auth.ChallengeType\x12\x0f\n\x07session\x18\x02 \x01(\t\x12\x10\n\x08response\x18\x03 \x01(\tB\x06\n\x04\x63\x61se\"N\n\rTokenResponse\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x10\n\x08id_token\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\"\xe6\x01\n\rLoginResponse\x12\x34\n\x0etoken_response\x18\x01 \x01(\x0b\x32\x1a.batchx.auth.TokenResponseH\x00\x12H\n\x11\x63hallenge_request\x18\x02 \x01(\x0b\x32+.batchx.auth.LoginResponse.ChallengeRequestH\x00\x1aM\n\x10\x43hallengeRequest\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.batchx.auth.ChallengeType\x12\x0f\n\x07session\x18\x02 \x01(\tB\x06\n\x04\x63\x61se\"*\n\x15\x46orgotPasswordRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\"\x18\n\x16\x46orgotPasswordResponse\"b\n\x1c\x43onfirmForgotPasswordRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\"\x1f\n\x1d\x43onfirmForgotPasswordResponse*G\n\nAuthStatus\x12\x0c\n\x08\x43OGINITO\x10\x00\x12\x1f\n\x1b\x43OGINITO_EMAIL_NOT_VERIFIED\x10\x01\x12\n\n\x06GOOGLE\x10\n*N\n\rChallengeType\x12\x15\n\x11UNKNOWN_CHALLENGE\x10\x00\x12\x19\n\x15NEW_PASSWORD_REQUIRED\x10\x01\x12\x0b\n\x07SMS_MFA\x10\x02\x32\xff\x07\n\x0b\x41uthService\x12>\n\x05Login\x12\x19.batchx.auth.LoginRequest\x1a\x1a.batchx.auth.LoginResponse\x12Y\n\x0e\x46orgotPassword\x12\".batchx.auth.ForgotPasswordRequest\x1a#.batchx.auth.ForgotPasswordResponse\x12n\n\x15\x43onfirmForgotPassword\x12).batchx.auth.ConfirmForgotPasswordRequest\x1a*.batchx.auth.ConfirmForgotPasswordResponse\x12S\n\x0cRefreshToken\x12 .batchx.auth.RefreshTokenRequest\x1a!.batchx.auth.RefreshTokenResponse\x12\x65\n\x12RevokeRefreshToken\x12&.batchx.auth.RevokeRefreshTokenRequest\x1a\'.batchx.auth.RevokeRefreshTokenResponse\x12\x41\n\x06Signup\x12\x1a.batchx.auth.SignupRequest\x1a\x1b.batchx.auth.SignupResponse\x12V\n\rConfirmSignup\x12!.batchx.auth.ConfirmSignupRequest\x1a\".batchx.auth.ConfirmSignupResponse\x12S\n\x0cGoogleSignin\x12 .batchx.auth.GoogleSigninRequest\x1a!.batchx.auth.GoogleSigninResponse\x12S\n\x0cGoogleSignup\x12 .batchx.auth.GoogleSignupRequest\x1a!.batchx.auth.GoogleSignupResponse\x12\x83\x01\n\x1cResendSignupConfirmationCode\x12\x30.batchx.auth.ResendSignupConfirmationCodeRequest\x1a\x31.batchx.auth.ResendSignupConfirmationCodeResponse\x12P\n\x0bStartSignup\x12\x1f.batchx.auth.StartSignupRequest\x1a .batchx.auth.StartSignupResponse\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x02\x42\x1c\n\x0fio.batchx.protoB\tAuthProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\tAuthProto'
  _AUTHSERVICE._options = None
  _AUTHSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\002'
  _AUTHSTATUS._serialized_start=1685
  _AUTHSTATUS._serialized_end=1756
  _CHALLENGETYPE._serialized_start=1758
  _CHALLENGETYPE._serialized_end=1836
  _STARTSIGNUPREQUEST._serialized_start=41
  _STARTSIGNUPREQUEST._serialized_end=76
  _STARTSIGNUPRESPONSE._serialized_start=78
  _STARTSIGNUPRESPONSE._serialized_end=99
  _GOOGLESIGNINREQUEST._serialized_start=101
  _GOOGLESIGNINREQUEST._serialized_end=140
  _GOOGLESIGNINRESPONSE._serialized_start=142
  _GOOGLESIGNINRESPONSE._serialized_end=216
  _GOOGLESIGNUPREQUEST._serialized_start=218
  _GOOGLESIGNUPREQUEST._serialized_end=330
  _GOOGLESIGNUPRESPONSE._serialized_start=332
  _GOOGLESIGNUPRESPONSE._serialized_end=354
  _SIGNUPREQUEST._serialized_start=357
  _SIGNUPREQUEST._serialized_end=517
  _SIGNUPRESPONSE._serialized_start=519
  _SIGNUPRESPONSE._serialized_end=535
  _CONFIRMSIGNUPREQUEST._serialized_start=537
  _CONFIRMSIGNUPREQUEST._serialized_end=600
  _CONFIRMSIGNUPRESPONSE._serialized_start=602
  _CONFIRMSIGNUPRESPONSE._serialized_end=625
  _RESENDSIGNUPCONFIRMATIONCODEREQUEST._serialized_start=627
  _RESENDSIGNUPCONFIRMATIONCODEREQUEST._serialized_end=678
  _RESENDSIGNUPCONFIRMATIONCODERESPONSE._serialized_start=680
  _RESENDSIGNUPCONFIRMATIONCODERESPONSE._serialized_end=718
  _REFRESHTOKENREQUEST._serialized_start=720
  _REFRESHTOKENREQUEST._serialized_end=783
  _REFRESHTOKENRESPONSE._serialized_start=785
  _REFRESHTOKENRESPONSE._serialized_end=829
  _REVOKEREFRESHTOKENREQUEST._serialized_start=831
  _REVOKEREFRESHTOKENREQUEST._serialized_end=900
  _REVOKEREFRESHTOKENRESPONSE._serialized_start=902
  _REVOKEREFRESHTOKENRESPONSE._serialized_end=930
  _LOGINREQUEST._serialized_start=933
  _LOGINREQUEST._serialized_end=1167
  _LOGINREQUEST_CHALLENGERESPONSE._serialized_start=1063
  _LOGINREQUEST_CHALLENGERESPONSE._serialized_end=1159
  _TOKENRESPONSE._serialized_start=1169
  _TOKENRESPONSE._serialized_end=1247
  _LOGINRESPONSE._serialized_start=1250
  _LOGINRESPONSE._serialized_end=1480
  _LOGINRESPONSE_CHALLENGEREQUEST._serialized_start=1395
  _LOGINRESPONSE_CHALLENGEREQUEST._serialized_end=1472
  _FORGOTPASSWORDREQUEST._serialized_start=1482
  _FORGOTPASSWORDREQUEST._serialized_end=1524
  _FORGOTPASSWORDRESPONSE._serialized_start=1526
  _FORGOTPASSWORDRESPONSE._serialized_end=1550
  _CONFIRMFORGOTPASSWORDREQUEST._serialized_start=1552
  _CONFIRMFORGOTPASSWORDREQUEST._serialized_end=1650
  _CONFIRMFORGOTPASSWORDRESPONSE._serialized_start=1652
  _CONFIRMFORGOTPASSWORDRESPONSE._serialized_end=1683
  _AUTHSERVICE._serialized_start=1839
  _AUTHSERVICE._serialized_end=2862
# @@protoc_insertion_point(module_scope)
