# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tag.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttag.proto\x12\nbatchx.tag\x1a\x0c\x63ommon.proto\"@\n\rGetTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\".\n\x0eGetTagResponse\x12\x1c\n\x03tag\x18\x01 \x01(\x0b\x32\x0f.batchx.tag.Tag\"1\n\x0eTagCoordinates\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x05\"M\n\x07TagData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\x08\"\x8f\x02\n\x03Tag\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12(\n\x07metrics\x18\x04 \x01(\x0b\x32\x17.batchx.tag.Tag.Metrics\x12\x13\n\x0bts_creation\x18\x05 \x01(\x03\x12\x18\n\x10ts_last_modified\x18\x06 \x01(\x03\x1aI\n\x07Metrics\x12\x0e\n\x06images\x18\x01 \x01(\x05\x12\x0c\n\x04jobs\x18\x02 \x01(\x05\x12\x11\n\tworkflows\x18\x03 \x01(\x05\x12\r\n\x05\x66iles\x18\x04 \x01(\x05\"\xf9\x01\n\x1aListEnvironmentTagsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x17\n\x0fonly_categories\x18\x03 \x01(\x08\x12=\n\x06\x66ilter\x18\x04 \x01(\x0b\x32-.batchx.tag.ListEnvironmentTagsRequest.Filter\x1a^\n\x06\x46ilter\x12\x17\n\rused_in_tools\x18\x01 \x01(\x08H\x00\x12\x16\n\x0cused_in_jobs\x18\x02 \x01(\x08H\x00\x12\x1b\n\x11used_in_workflows\x18\x03 \x01(\x08H\x00\x42\x06\n\x04\x43\x61se\";\n\x1bListEnvironmentTagsResponse\x12\x1c\n\x03tag\x18\x01 \x03(\x0b\x32\x0f.batchx.tag.Tag\"J\n\x10\x43reateTagRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\"D\n\x11\x43reateTagResponse\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\"T\n\x11\x44isableTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"C\n\x10\x44\x65leteTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\"\x13\n\x11\x44\x65leteTagResponse\"\x14\n\x12\x44isableTagResponse\"f\n\x10UpdateTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\"\x13\n\x11UpdateTagResponse2\x8c\x04\n\nTagService\x12\x44\n\x06GetTag\x12\x19.batchx.tag.GetTagRequest\x1a\x1a.batchx.tag.GetTagResponse\"\x03\x90\x02\x01\x12k\n\x13ListEnvironmentTags\x12&.batchx.tag.ListEnvironmentTagsRequest\x1a\'.batchx.tag.ListEnvironmentTagsResponse\"\x03\x90\x02\x01\x12M\n\tCreateTag\x12\x1c.batchx.tag.CreateTagRequest\x1a\x1d.batchx.tag.CreateTagResponse\"\x03\x90\x02\x02\x12P\n\nDisableTag\x12\x1d.batchx.tag.DisableTagRequest\x1a\x1e.batchx.tag.DisableTagResponse\"\x03\x90\x02\x02\x12M\n\tDeleteTag\x12\x1c.batchx.tag.DeleteTagRequest\x1a\x1d.batchx.tag.DeleteTagResponse\"\x03\x90\x02\x02\x12M\n\tUpdateTag\x12\x1c.batchx.tag.UpdateTagRequest\x1a\x1d.batchx.tag.UpdateTagResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1b\n\x0fio.batchx.protoB\x08TagProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tag_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\010TagProto'
  _TAGSERVICE._options = None
  _TAGSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _TAGSERVICE.methods_by_name['GetTag']._options = None
  _TAGSERVICE.methods_by_name['GetTag']._serialized_options = b'\220\002\001'
  _TAGSERVICE.methods_by_name['ListEnvironmentTags']._options = None
  _TAGSERVICE.methods_by_name['ListEnvironmentTags']._serialized_options = b'\220\002\001'
  _TAGSERVICE.methods_by_name['CreateTag']._options = None
  _TAGSERVICE.methods_by_name['CreateTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['DisableTag']._options = None
  _TAGSERVICE.methods_by_name['DisableTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['DeleteTag']._options = None
  _TAGSERVICE.methods_by_name['DeleteTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['UpdateTag']._options = None
  _TAGSERVICE.methods_by_name['UpdateTag']._serialized_options = b'\220\002\002'
  _GETTAGREQUEST._serialized_start=39
  _GETTAGREQUEST._serialized_end=103
  _GETTAGRESPONSE._serialized_start=105
  _GETTAGRESPONSE._serialized_end=151
  _TAGCOORDINATES._serialized_start=153
  _TAGCOORDINATES._serialized_end=202
  _TAGDATA._serialized_start=204
  _TAGDATA._serialized_end=281
  _TAG._serialized_start=284
  _TAG._serialized_end=555
  _TAG_METRICS._serialized_start=482
  _TAG_METRICS._serialized_end=555
  _LISTENVIRONMENTTAGSREQUEST._serialized_start=558
  _LISTENVIRONMENTTAGSREQUEST._serialized_end=807
  _LISTENVIRONMENTTAGSREQUEST_FILTER._serialized_start=713
  _LISTENVIRONMENTTAGSREQUEST_FILTER._serialized_end=807
  _LISTENVIRONMENTTAGSRESPONSE._serialized_start=809
  _LISTENVIRONMENTTAGSRESPONSE._serialized_end=868
  _CREATETAGREQUEST._serialized_start=870
  _CREATETAGREQUEST._serialized_end=944
  _CREATETAGRESPONSE._serialized_start=946
  _CREATETAGRESPONSE._serialized_end=1014
  _DISABLETAGREQUEST._serialized_start=1016
  _DISABLETAGREQUEST._serialized_end=1100
  _DELETETAGREQUEST._serialized_start=1102
  _DELETETAGREQUEST._serialized_end=1169
  _DELETETAGRESPONSE._serialized_start=1171
  _DELETETAGRESPONSE._serialized_end=1190
  _DISABLETAGRESPONSE._serialized_start=1192
  _DISABLETAGRESPONSE._serialized_end=1212
  _UPDATETAGREQUEST._serialized_start=1214
  _UPDATETAGREQUEST._serialized_end=1316
  _UPDATETAGRESPONSE._serialized_start=1318
  _UPDATETAGRESPONSE._serialized_end=1337
  _TAGSERVICE._serialized_start=1340
  _TAGSERVICE._serialized_end=1864
# @@protoc_insertion_point(module_scope)
