# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import profile_pb2 as profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x0b\x62\x61tchx.user\x1a\x0c\x63ommon.proto\x1a\rprofile.proto\"e\n\x11UpdateUserRequest\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12(\n\x07profile\x18\x02 \x01(\x0b\x32\x17.batchx.profile.Profile\"\x14\n\x12UpdateUserResponse\"7\n\x0eGetUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x17\n\x0finclude_profile\x18\x02 \x01(\x08\"\xb8\x02\n\x0fGetUserResponse\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12\x36\n\x11organization_data\x18\x02 \x03(\x0b\x32\x1b.batchx.common.Organization\x12(\n\x07profile\x18\x03 \x01(\x0b\x32\x17.batchx.profile.Profile\x12@\n\nmembership\x18\x04 \x03(\x0b\x32,.batchx.user.GetUserResponse.MembershipEntry\x1aY\n\x0fMembershipEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.batchx.common.Organization.Membership:\x02\x38\x01\x32\xba\x01\n\x0bUserService\x12I\n\x07GetUser\x12\x1b.batchx.user.GetUserRequest\x1a\x1c.batchx.user.GetUserResponse\"\x03\x90\x02\x01\x12R\n\nUpdateUser\x12\x1e.batchx.user.UpdateUserRequest\x1a\x1f.batchx.user.UpdateUserResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x05\x82\x97\"\x02\x10\x01\x42\x1c\n\x0fio.batchx.protoB\tUserProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\tUserProto'
  _GETUSERRESPONSE_MEMBERSHIPENTRY._options = None
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_options = b'8\001'
  _USERSERVICE._options = None
  _USERSERVICE._serialized_options = b'\202\227\"\002\010\005\202\227\"\002\020\001'
  _USERSERVICE.methods_by_name['GetUser']._options = None
  _USERSERVICE.methods_by_name['GetUser']._serialized_options = b'\220\002\001'
  _USERSERVICE.methods_by_name['UpdateUser']._options = None
  _USERSERVICE.methods_by_name['UpdateUser']._serialized_options = b'\220\002\002'
  _UPDATEUSERREQUEST._serialized_start=56
  _UPDATEUSERREQUEST._serialized_end=157
  _UPDATEUSERRESPONSE._serialized_start=159
  _UPDATEUSERRESPONSE._serialized_end=179
  _GETUSERREQUEST._serialized_start=181
  _GETUSERREQUEST._serialized_end=236
  _GETUSERRESPONSE._serialized_start=239
  _GETUSERRESPONSE._serialized_end=551
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_start=462
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_end=551
  _USERSERVICE._serialized_start=554
  _USERSERVICE._serialized_end=740
# @@protoc_insertion_point(module_scope)
