# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: audit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61udit.proto\x12\x0c\x62\x61tchx.audit\x1a\x0c\x63ommon.proto\"\x9a\x01\n\x05\x45vent\x12\x13\n\x0bts_creation\x18\x01 \x01(\x03\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.batchx.audit.EventType\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0e\n\x06object\x18\x07 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x08 \x01(\x03\"\xde\x05\n\x11ListEventsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x34\n\x05order\x18\x03 \x01(\x0b\x32%.batchx.audit.ListEventsRequest.Order\x12>\n\npagination\x18\x04 \x01(\x0b\x32*.batchx.audit.ListEventsRequest.Pagination\x12<\n\tfiltering\x18\x05 \x01(\x0b\x32).batchx.audit.ListEventsRequest.Filtering\x1a\x95\x01\n\x05Order\x12?\n\x08order_by\x18\x01 \x01(\x0e\x32-.batchx.audit.ListEventsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"\'\n\x07OrderBy\x12\x0f\n\x0bTS_CREATION\x10\x00\x12\x0b\n\x07\x42\x41LANCE\x10\x01\x1a\xbe\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x43\n\x07memento\x18\x02 \x01(\x0b\x32\x32.batchx.audit.ListEventsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a=\n\x07Memento\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x13\n\x0bts_creation\x18\x02 \x01(\x03\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x03\x1a\xa6\x01\n\tFiltering\x12\x33\n\x0bts_creation\x18\x01 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12/\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x03 \x03(\t\x12%\n\x04type\x18\x04 \x03(\x0e\x32\x17.batchx.audit.EventType\"\x80\x02\n\x12ListEventsResponse\x12\"\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x13.batchx.audit.Event\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x41\n\tuser_data\x18\x04 \x03(\x0b\x32..batchx.audit.ListEventsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01*\xb7\x06\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rFILE_DOWNLOAD\x10\x01\x12\x0f\n\x0b\x46ILE_UPLOAD\x10\x02\x12\x0f\n\x0b\x46ILE_DELETE\x10\x03\x12\r\n\tFILE_COPY\x10\x04\x12\x0e\n\nFILE_SHARE\x10\x05\x12\x10\n\x0c\x46ILE_UNSHARE\x10\x06\x12\x10\n\x0cIMAGE_IMPORT\x10\n\x12\x0f\n\x0bIMAGE_SHARE\x10\x0b\x12\x11\n\rIMAGE_UNSHARE\x10\x0c\x12\x0f\n\x0bIMAGE_CLONE\x10\r\x12\x11\n\rIMAGE_UNCLONE\x10\x0e\x12\x10\n\x0cIMAGE_DELETE\x10\x0f\x12\x15\n\x11IMAGE_SET_EXAMPLE\x10\x10\x12\x18\n\x14IMAGE_REMOVE_EXAMPLE\x10\x11\x12\x18\n\x14IMAGE_CLONE_EXAMPLES\x10\x12\x12\x1a\n\x16IMAGE_UNCLONE_EXAMPLES\x10\x13\x12\x0e\n\nJOB_LAUNCH\x10\x14\x12\x0e\n\nJOB_DELETE\x10\x15\x12\x0e\n\nJOB_CANCEL\x10\x16\x12\x13\n\x0fWORKFLOW_LAUNCH\x10\x1f\x12\x13\n\x0fWORKFLOW_DELETE\x10 \x12\x16\n\x12ORG_CHANGE_PROFILE\x10(\x12\x12\n\x0eORG_ADD_MEMBER\x10)\x12\x15\n\x11ORG_REMOVE_MEMBER\x10*\x12\x15\n\x11ORG_CHANGE_MEMBER\x10+\x12\x16\n\x12USER_LOGIN_ATTEMPT\x10\x32\x12\x18\n\x14USER_LOGIN_SUCCEEDED\x10\x33\x12\x19\n\x15USER_RECOVER_PASSWORD\x10\x34\x12 \n\x1cUSER_CHANGE_PASSWORD_ATTEMPT\x10\x35\x12\"\n\x1eUSER_CHANGE_PASSWORD_SUCCEEDED\x10\x36\x12\x17\n\x13USER_CHANGE_PROFILE\x10\x37\x12\x18\n\x14\x42LOB_DELETE_ARCHIVED\x10<\x12\x10\n\x0c\x42LOB_RESTORE\x10=\x12\x10\n\x0c\x42LOB_ARCHIVE\x10>\x12\x14\n\x10\x42LOB_DELETE_LIVE\x10?\x12\x13\n\x0f\x45NV_ADD_CREDITS\x10\x46\x12\x1b\n\x17\x45NV_TRANSFERRED_CREDITS\x10G2r\n\x0c\x41uditService\x12T\n\nListEvents\x12\x1f.batchx.audit.ListEventsRequest\x1a .batchx.audit.ListEventsResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42\x1d\n\x0fio.batchx.protoB\nAuditProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'audit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nAuditProto'
  _LISTEVENTSRESPONSE_USERDATAENTRY._options = None
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _AUDITSERVICE._options = None
  _AUDITSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _AUDITSERVICE.methods_by_name['ListEvents']._options = None
  _AUDITSERVICE.methods_by_name['ListEvents']._serialized_options = b'\220\002\001'
  _EVENTTYPE._serialized_start=1197
  _EVENTTYPE._serialized_end=2020
  _EVENT._serialized_start=44
  _EVENT._serialized_end=198
  _LISTEVENTSREQUEST._serialized_start=201
  _LISTEVENTSREQUEST._serialized_end=935
  _LISTEVENTSREQUEST_ORDER._serialized_start=424
  _LISTEVENTSREQUEST_ORDER._serialized_end=573
  _LISTEVENTSREQUEST_ORDER_ORDERBY._serialized_start=534
  _LISTEVENTSREQUEST_ORDER_ORDERBY._serialized_end=573
  _LISTEVENTSREQUEST_PAGINATION._serialized_start=576
  _LISTEVENTSREQUEST_PAGINATION._serialized_end=766
  _LISTEVENTSREQUEST_PAGINATION_MEMENTO._serialized_start=705
  _LISTEVENTSREQUEST_PAGINATION_MEMENTO._serialized_end=766
  _LISTEVENTSREQUEST_FILTERING._serialized_start=769
  _LISTEVENTSREQUEST_FILTERING._serialized_end=935
  _LISTEVENTSRESPONSE._serialized_start=938
  _LISTEVENTSRESPONSE._serialized_end=1194
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_start=1126
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_end=1194
  _AUDITSERVICE._serialized_start=2022
  _AUDITSERVICE._serialized_end=2136
# @@protoc_insertion_point(module_scope)
