# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import log_pb2 as log__pb2
from . import tag_pb2 as tag__pb2
from . import common_pb2 as common__pb2
from . import filesystem_pb2 as filesystem__pb2
from . import image_pb2 as image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tjob.proto\x12\nbatchx.job\x1a\tlog.proto\x1a\ttag.proto\x1a\x0c\x63ommon.proto\x1a\x10\x66ilesystem.proto\x1a\x0bimage.proto\"x\n\x1bGetComputationalCostRequest\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamily\"\x92\x01\n\x1cGetComputationalCostResponse\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x17\n\x0f\x63ost_per_second\x18\x05 \x01(\x03\"\xf9\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12\x11\n\tts_submit\x18\x03 \x01(\x03\x12\x10\n\x08ts_start\x18\x04 \x01(\x03\x12\x11\n\tts_finish\x18\x05 \x01(\x03\x12\"\n\x06status\x18\x06 \x01(\x0e\x32\x12.batchx.job.Status\x12\r\n\x05vcpus\x18\x07 \x01(\x05\x12\x0e\n\x06memory\x18\x08 \x01(\x05\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\n\n\x02\x62y\x18\n \x01(\t\x12\x12\n\ninput_hash\x18\x0b \x01(\t\x12\x12\n\ninput_size\x18\x0c \x01(\x03\x12\x0c\n\x04gpus\x18\r \x01(\x05\x12\x11\n\texit_code\x18\x0e \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12,\n\ngpu_family\x18\x10 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x15\n\rerror_message\x18\x11 \x01(\t\x12\x13\n\x0boutput_size\x18\x12 \x01(\x03\x12\x13\n\x0bworkflow_id\x18\x13 \x01(\x05\x12\x0e\n\x06\x63\x61\x63hed\x18\x14 \x01(\x08\x12\x1c\n\x03tag\x18\x15 \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x1b\n\x13original_input_json\x18\x16 \x01(\t\x12\x12\n\ninput_json\x18\x17 \x01(\t\x12\x13\n\x0boutput_json\x18\x18 \x01(\t\x12#\n\x1b\x63omputation_cost_per_second\x18\x19 \x01(\x03\x12\x12\n\nimage_cost\x18\x1a \x01(\x03\x12\x0f\n\x07runtime\x18\x1b \x01(\x03\x12\x12\n\ntotal_cost\x18\x1c \x01(\x03\x12\x11\n\tlogs_size\x18\x1d \x01(\x03\x12\x1d\n\x15workflow_orchestrator\x18\x1e \x01(\x08\x12\x38\n\rimage_pricing\x18\x1f \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x12\x1b\n\x13\x62illing_input_lines\x18  \x01(\x03\x12\x1b\n\x13\x62illing_input_bytes\x18! \x01(\x03\"\xbb\x03\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\x12\x10\n\x08ts_start\x18\x03 \x01(\x03\x12\x11\n\tts_finish\x18\x04 \x01(\x03\x12\x33\n\x06status\x18\x05 \x01(\x0e\x32#.batchx.job.Workflow.WorkflowStatus\x12\x12\n\njobs_count\x18\x06 \x01(\x05\x12\x13\n\x0btotal_price\x18\x07 \x01(\x03\x12\n\n\x02\x62y\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\t \x01(\x08\x12\x1c\n\x03tag\x18\n \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x18\n\x10ts_last_activity\x18\x0b \x01(\x03\x12\x19\n\x11\x61\x63tive_jobs_count\x18\x0c \x01(\x05\x12\x15\n\rerror_message\x18\r \x01(\t\x12\x11\n\tparent_id\x18\x0e \x01(\x05\x12\x17\n\x0forchestrator_id\x18\x0f \x01(\x05\"^\n\x0eWorkflowStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04OPEN\x10\n\x12\n\n\x06\x43LOSED\x10\x32\x12\r\n\tSUCCEEDED\x10\x64\x12\r\n\x08INACTIVE\x10\xc8\x01\x12\x0b\n\x06\x46\x41ILED\x10\xac\x02\"O\n\x15\x43reateWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"\'\n\x16\x43reateWorkflowResponse\x12\r\n\x05token\x18\x01 \x01(\t\"W\n\x14\x43loseWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\tJ\x04\x08\x03\x10\x04\"\x17\n\x15\x43loseWorkflowResponse\"4\n\rGetJobRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"n\n\rTagJobRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12(\n\x04tags\x18\x03 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x04 \x01(\x08\"\x10\n\x0eTagJobResponse\"x\n\x12TagWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12(\n\x04tags\x18\x03 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x04 \x01(\x08\"\x15\n\x13TagWorkflowResponse\"b\n\x0eGetJobResponse\x12\x1c\n\x03job\x18\x01 \x01(\x0b\x32\x0f.batchx.job.Job\x12&\n\tuser_data\x18\x04 \x01(\x0b\x32\x13.batchx.common.UserJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\">\n\x12GetWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"k\n\x13GetWorkflowResponse\x12&\n\x08workflow\x18\x01 \x01(\x0b\x32\x14.batchx.job.Workflow\x12&\n\tuser_data\x18\x03 \x01(\x0b\x32\x13.batchx.common.UserJ\x04\x08\x02\x10\x03\"C\n\x17GetWorkflowGraphRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"\x89\x06\n\x18GetWorkflowGraphResponse\x12\x37\n\x04node\x18\x01 \x03(\x0b\x32).batchx.job.GetWorkflowGraphResponse.Node\x12\x37\n\x04\x65\x64ge\x18\x02 \x03(\x0b\x32).batchx.job.GetWorkflowGraphResponse.Edge\x1a\xe4\x03\n\nJobMetrics\x12\\\n\x0fstatus_counters\x18\x01 \x03(\x0b\x32\x43.batchx.job.GetWorkflowGraphResponse.JobMetrics.StatusCountersEntry\x12R\n\rimage_credits\x18\x02 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x12X\n\x13\x63omputation_credits\x18\x03 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x12L\n\x07runtime\x18\x04 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x1a\x35\n\x13StatusCountersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x45\n\x0bLongMetrics\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x03\x12\x0b\n\x03sum\x18\x04 \x01(\x03\x1al\n\x04Node\x12\r\n\x05image\x18\x01 \x01(\t\x12\x10\n\x08pipeline\x18\x02 \x01(\x08\x12\x43\n\njobMetrics\x18\x03 \x01(\x0b\x32/.batchx.job.GetWorkflowGraphResponse.JobMetrics\x1a&\n\x04\x45\x64ge\x12\x0e\n\x06source\x18\x01 \x01(\x05\x12\x0e\n\x06target\x18\x02 \x01(\x05\"\xbc\x0b\n\x0fListJobsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x30\n\x05order\x18\x03 \x01(\x0b\x32!.batchx.job.ListJobsRequest.Order\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.batchx.job.ListJobsRequest.Pagination\x12\x38\n\tfiltering\x18\x05 \x01(\x0b\x32%.batchx.job.ListJobsRequest.Filtering\x1a\xf0\x01\n\x05Order\x12;\n\x08order_by\x18\x01 \x01(\x0e\x32).batchx.job.ListJobsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"\x85\x01\n\x07OrderBy\x12\x06\n\x02ID\x10\x00\x12\r\n\tTS_FINISH\x10\x01\x12\x14\n\x10\x43OMPUTATION_COST\x10\x02\x12\x0e\n\nIMAGE_COST\x10\x03\x12\x0b\n\x07RUNTIME\x10\x04\x12\x0e\n\nINPUT_SIZE\x10\x05\x12\x0f\n\x0bOUTPUT_SIZE\x10\x06\x12\x0f\n\x0bWORKFLOW_ID\x10\x07\x1a\x8e\x02\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12?\n\x07memento\x18\x02 \x01(\x0b\x32..batchx.job.ListJobsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a\x90\x01\n\x07Memento\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tts_finish\x18\x02 \x01(\x03\x12\x18\n\x10\x63omputation_cost\x18\x03 \x01(\x03\x12\x12\n\nimage_cost\x18\x04 \x01(\x03\x12\x0f\n\x07runtime\x18\x05 \x01(\x03\x12\x12\n\ninput_size\x18\x06 \x01(\x03\x12\x13\n\x0boutput_size\x18\x07 \x01(\x03\x1a\xe1\x05\n\tFiltering\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12@\n\x05image\x18\x02 \x03(\x0b\x32\x31.batchx.job.ListJobsRequest.Filtering.ImageFilter\x12\x31\n\tsubmitted\x18\x03 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x32\n\ninput_size\x18\x05 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x33\n\x0boutput_size\x18\x06 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\"\n\x06status\x18\x07 \x03(\x0e\x32\x12.batchx.job.Status\x12/\n\x07runtime\x18\x08 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\nimage_cost\x18\t \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x38\n\x10\x63omputation_cost\x18\n \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\ntotal_cost\x18\x0b \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\'\n\x03tag\x18\x0c \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x32\n\x0bworkflow_id\x18\r \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12\x14\n\x0cshow_deleted\x18\x0e \x01(\x08\x1aS\n\x0bImageFilter\x12\x19\n\x11image_environment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x15\n\rimage_version\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"\xfa\x01\n\x10ListJobsResponse\x12\x1c\n\x03job\x18\x01 \x03(\x0b\x32\x0f.batchx.job.Job\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12=\n\tuser_data\x18\x04 \x03(\x0b\x32*.batchx.job.ListJobsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01J\x04\x08\x03\x10\x04\"\x84\x08\n\x14ListWorkflowsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x35\n\x05order\x18\x03 \x01(\x0b\x32&.batchx.job.ListWorkflowsRequest.Order\x12?\n\npagination\x18\x04 \x01(\x0b\x32+.batchx.job.ListWorkflowsRequest.Pagination\x12=\n\tfiltering\x18\x05 \x01(\x0b\x32*.batchx.job.ListWorkflowsRequest.Filtering\x1a\xb0\x01\n\x05Order\x12@\n\x08order_by\x18\x01 \x01(\x0e\x32..batchx.job.ListWorkflowsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"A\n\x07OrderBy\x12\x06\n\x02ID\x10\x00\x12\r\n\tTS_FINISH\x10\x01\x12\x08\n\x04JOBS\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\x08\n\x04\x43OST\x10\x04\x1a\xd7\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x44\n\x07memento\x18\x02 \x01(\x0b\x32\x33.batchx.job.ListWorkflowsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1aU\n\x07Memento\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tts_finish\x18\x02 \x01(\x03\x12\x0c\n\x04jobs\x18\x03 \x01(\x05\x12\x0f\n\x07runtime\x18\x04 \x01(\x03\x12\x0c\n\x04\x63ost\x18\x05 \x01(\x03\x1a\x8c\x03\n\tFiltering\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12\r\n\x05label\x18\x02 \x01(\t\x12\x31\n\tsubmitted\x18\x03 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x33\n\x06status\x18\x05 \x03(\x0e\x32#.batchx.job.Workflow.WorkflowStatus\x12+\n\x04jobs\x18\x06 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12/\n\x07runtime\x18\x07 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\ntotal_cost\x18\x08 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\'\n\x03tag\x18\t \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x14\n\x0cshow_deleted\x18\n \x01(\x08J\x04\x08\x02\x10\x03\"\x8e\x02\n\x15ListWorkflowsResponse\x12&\n\x08workflow\x18\x01 \x03(\x0b\x32\x14.batchx.job.Workflow\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x42\n\tuser_data\x18\x04 \x03(\x0b\x32/.batchx.job.ListWorkflowsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01J\x04\x08\x03\x10\x04\"\xa6\x02\n\rSubmitRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\r\n\x05vcpus\x18\x03 \x01(\x05\x12\x0e\n\x06memory\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x0c\n\x04gpus\x18\x06 \x01(\x05\x12\x14\n\x0cretry_job_id\x18\x07 \x01(\x05\x12\x10\n\x08no_cache\x18\x08 \x01(\x08\x12,\n\ngpu_family\x18\t \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x1d\n\x15no_suggest_parameters\x18\n \x01(\x08\x12\x16\n\x0eworkflow_token\x18\x0b \x01(\t\x12\x12\n\ninput_json\x18\x0c \x01(\t\x12\x12\n\nrequest_id\x18\r \x01(\t\"\xec\x01\n\x0eSubmitResponse\x12\x10\n\x06job_id\x18\x01 \x01(\x05H\x00\x12N\n\x14suggested_parameters\x18\x02 \x01(\x0b\x32..batchx.job.SubmitResponse.SuggestedParametersH\x00\x1ap\n\x13SuggestedParameters\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamilyB\x06\n\x04\x63\x61se\"J\n\rStreamRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\x14\n\x0clogs_enabled\x18\x03 \x01(\x08\"5\n\x0eStreamResponse\x12#\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x14.batchx.job.JobEvent\"V\n\x0eGetLogsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x10\n\x08\x62\x61\x63kward\x18\x04 \x01(\x08\"4\n\rCancelRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"\x10\n\x0e\x43\x61ncelResponse\"4\n\rDeleteRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"\x10\n\x0e\x44\x65leteResponse\"A\n\x15\x44\x65leteWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"-\n\x16\x44\x65leteWorkflowResponse\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\x05\"\xfb\x03\n\x08JobEvent\x12+\n\nlog_record\x18\x01 \x01(\x0b\x32\x15.batchx.log.LogRecordH\x00\x12(\n\njob_status\x18\x02 \x01(\x0e\x32\x12.batchx.job.StatusH\x00\x12\x38\n\x0creturn_value\x18\x03 \x01(\x0b\x32 .batchx.job.JobEvent.ReturnValueH\x00\x12\x1f\n\x15\x63ompletion_percentage\x18\x04 \x01(\x05H\x00\x12\x0f\n\x07message\x18\x05 \x01(\t\x1a\xa3\x02\n\x0bReturnValue\x12\x11\n\texit_code\x18\x01 \x01(\x05\x12\x13\n\x0boutput_json\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x13\n\x0boutput_size\x18\x04 \x01(\x03\x12J\n\x0e\x66ile_meta_info\x18\x05 \x03(\x0b\x32\x32.batchx.job.JobEvent.ReturnValue.FileMetaInfoEntry\x12\x1d\n\x15\x63ontainer_output_json\x18\x06 \x01(\t\x1aU\n\x11\x46ileMetaInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .batchx.filesystem.Blob.MetaInfo:\x02\x38\x01\x42\x06\n\x04type\"g\n\x0fJobStateMessage\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12#\n\x05\x65vent\x18\x03 \x03(\x0b\x32\x14.batchx.job.JobEvent\x12\n\n\x02ts\x18\x04 \x01(\x03*\x98\x02\n\x06Status\x12\r\n\tSUBMITTED\x10\x00\x12\x0e\n\nPROCESSING\x10\x32\x12\n\n\x06QUEUED\x10\x64\x12\r\n\x08STARTING\x10\xc8\x01\x12\x16\n\x11\x44OWNLOADING_INPUT\x10\xac\x02\x12\x0c\n\x07RUNNING\x10\x90\x03\x12\x15\n\x10UPLOADING_OUTPUT\x10\xf4\x03\x12\x0f\n\nCANCELLING\x10\xd8\x04\x12\x0e\n\tSUCCEEDED\x10\xbc\x05\x12\x0c\n\x07WARNING\x10\xee\x05\x12\x0b\n\x06\x46\x41ILED\x10\xa0\x06\x12\x0e\n\tTIMED_OUT\x10\x84\x07\x12\x0e\n\tCANCELLED\x10\xe8\x07\x12\x12\n\rOUT_OF_MEMORY\x10\xcc\x08\x12\x13\n\x0eINVALID_OUTPUT\x10\xb0\t\x12\x12\n\rINVALID_INPUT\x10\x94\n2\xfd\n\n\nJobService\x12\x44\n\x06GetJob\x12\x19.batchx.job.GetJobRequest\x1a\x1a.batchx.job.GetJobResponse\"\x03\x90\x02\x01\x12n\n\x14GetComputationalCost\x12\'.batchx.job.GetComputationalCostRequest\x1a(.batchx.job.GetComputationalCostResponse\"\x03\x90\x02\x01\x12V\n\x08ListJobs\x12\x1b.batchx.job.ListJobsRequest\x1a\x1c.batchx.job.ListJobsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12\x44\n\x06Submit\x12\x19.batchx.job.SubmitRequest\x1a\x1a.batchx.job.SubmitResponse\"\x03\x90\x02\x02\x12\x46\n\x06Stream\x12\x19.batchx.job.StreamRequest\x1a\x1a.batchx.job.StreamResponse\"\x03\x90\x02\x02\x30\x01\x12O\n\x07GetLogs\x12\x1a.batchx.job.GetLogsRequest\x1a\x15.batchx.log.LogRecord\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x30\x01\x12P\n\x06\x44\x65lete\x12\x19.batchx.job.DeleteRequest\x1a\x1a.batchx.job.DeleteResponse\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x12h\n\x0e\x44\x65leteWorkflow\x12!.batchx.job.DeleteWorkflowRequest\x1a\".batchx.job.DeleteWorkflowResponse\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x12\x44\n\x06\x43\x61ncel\x12\x19.batchx.job.CancelRequest\x1a\x1a.batchx.job.CancelResponse\"\x03\x90\x02\x02\x12\\\n\x0e\x43reateWorkflow\x12!.batchx.job.CreateWorkflowRequest\x1a\".batchx.job.CreateWorkflowResponse\"\x03\x90\x02\x02\x12Y\n\rCloseWorkflow\x12 .batchx.job.CloseWorkflowRequest\x1a!.batchx.job.CloseWorkflowResponse\"\x03\x90\x02\x02\x12\x65\n\rListWorkflows\x12 .batchx.job.ListWorkflowsRequest\x1a!.batchx.job.ListWorkflowsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12S\n\x0bGetWorkflow\x12\x1e.batchx.job.GetWorkflowRequest\x1a\x1f.batchx.job.GetWorkflowResponse\"\x03\x90\x02\x01\x12\x44\n\x06TagJob\x12\x19.batchx.job.TagJobRequest\x1a\x1a.batchx.job.TagJobResponse\"\x03\x90\x02\x02\x12S\n\x0bTagWorkflow\x12\x1e.batchx.job.TagWorkflowRequest\x1a\x1f.batchx.job.TagWorkflowResponse\"\x03\x90\x02\x02\x12\x62\n\x10GetWorkflowGraph\x12#.batchx.job.GetWorkflowGraphRequest\x1a$.batchx.job.GetWorkflowGraphResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1b\n\x0fio.batchx.protoB\x08JobProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\010JobProto'
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._options = None
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_options = b'8\001'
  _LISTJOBSRESPONSE_USERDATAENTRY._options = None
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._options = None
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._options = None
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_options = b'8\001'
  _JOBSERVICE._options = None
  _JOBSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _JOBSERVICE.methods_by_name['GetJob']._options = None
  _JOBSERVICE.methods_by_name['GetJob']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['GetComputationalCost']._options = None
  _JOBSERVICE.methods_by_name['GetComputationalCost']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['ListJobs']._options = None
  _JOBSERVICE.methods_by_name['ListJobs']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Submit']._options = None
  _JOBSERVICE.methods_by_name['Submit']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['Stream']._options = None
  _JOBSERVICE.methods_by_name['Stream']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['GetLogs']._options = None
  _JOBSERVICE.methods_by_name['GetLogs']._serialized_options = b'\220\002\001\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Delete']._options = None
  _JOBSERVICE.methods_by_name['Delete']._serialized_options = b'\220\002\002\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['DeleteWorkflow']._options = None
  _JOBSERVICE.methods_by_name['DeleteWorkflow']._serialized_options = b'\220\002\002\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Cancel']._options = None
  _JOBSERVICE.methods_by_name['Cancel']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['CreateWorkflow']._options = None
  _JOBSERVICE.methods_by_name['CreateWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['CloseWorkflow']._options = None
  _JOBSERVICE.methods_by_name['CloseWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['ListWorkflows']._options = None
  _JOBSERVICE.methods_by_name['ListWorkflows']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['GetWorkflow']._options = None
  _JOBSERVICE.methods_by_name['GetWorkflow']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['TagJob']._options = None
  _JOBSERVICE.methods_by_name['TagJob']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['TagWorkflow']._options = None
  _JOBSERVICE.methods_by_name['TagWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['GetWorkflowGraph']._options = None
  _JOBSERVICE.methods_by_name['GetWorkflowGraph']._serialized_options = b'\220\002\002'
  _STATUS._serialized_start=7917
  _STATUS._serialized_end=8197
  _GETCOMPUTATIONALCOSTREQUEST._serialized_start=92
  _GETCOMPUTATIONALCOSTREQUEST._serialized_end=212
  _GETCOMPUTATIONALCOSTRESPONSE._serialized_start=215
  _GETCOMPUTATIONALCOSTRESPONSE._serialized_end=361
  _JOB._serialized_start=364
  _JOB._serialized_end=1125
  _WORKFLOW._serialized_start=1128
  _WORKFLOW._serialized_end=1571
  _WORKFLOW_WORKFLOWSTATUS._serialized_start=1477
  _WORKFLOW_WORKFLOWSTATUS._serialized_end=1571
  _CREATEWORKFLOWREQUEST._serialized_start=1573
  _CREATEWORKFLOWREQUEST._serialized_end=1652
  _CREATEWORKFLOWRESPONSE._serialized_start=1654
  _CREATEWORKFLOWRESPONSE._serialized_end=1693
  _CLOSEWORKFLOWREQUEST._serialized_start=1695
  _CLOSEWORKFLOWREQUEST._serialized_end=1782
  _CLOSEWORKFLOWRESPONSE._serialized_start=1784
  _CLOSEWORKFLOWRESPONSE._serialized_end=1807
  _GETJOBREQUEST._serialized_start=1809
  _GETJOBREQUEST._serialized_end=1861
  _TAGJOBREQUEST._serialized_start=1863
  _TAGJOBREQUEST._serialized_end=1973
  _TAGJOBRESPONSE._serialized_start=1975
  _TAGJOBRESPONSE._serialized_end=1991
  _TAGWORKFLOWREQUEST._serialized_start=1993
  _TAGWORKFLOWREQUEST._serialized_end=2113
  _TAGWORKFLOWRESPONSE._serialized_start=2115
  _TAGWORKFLOWRESPONSE._serialized_end=2136
  _GETJOBRESPONSE._serialized_start=2138
  _GETJOBRESPONSE._serialized_end=2236
  _GETWORKFLOWREQUEST._serialized_start=2238
  _GETWORKFLOWREQUEST._serialized_end=2300
  _GETWORKFLOWRESPONSE._serialized_start=2302
  _GETWORKFLOWRESPONSE._serialized_end=2409
  _GETWORKFLOWGRAPHREQUEST._serialized_start=2411
  _GETWORKFLOWGRAPHREQUEST._serialized_end=2478
  _GETWORKFLOWGRAPHRESPONSE._serialized_start=2481
  _GETWORKFLOWGRAPHRESPONSE._serialized_end=3258
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS._serialized_start=2624
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS._serialized_end=3108
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_start=2984
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_end=3037
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_LONGMETRICS._serialized_start=3039
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_LONGMETRICS._serialized_end=3108
  _GETWORKFLOWGRAPHRESPONSE_NODE._serialized_start=3110
  _GETWORKFLOWGRAPHRESPONSE_NODE._serialized_end=3218
  _GETWORKFLOWGRAPHRESPONSE_EDGE._serialized_start=3220
  _GETWORKFLOWGRAPHRESPONSE_EDGE._serialized_end=3258
  _LISTJOBSREQUEST._serialized_start=3261
  _LISTJOBSREQUEST._serialized_end=4729
  _LISTJOBSREQUEST_ORDER._serialized_start=3470
  _LISTJOBSREQUEST_ORDER._serialized_end=3710
  _LISTJOBSREQUEST_ORDER_ORDERBY._serialized_start=3577
  _LISTJOBSREQUEST_ORDER_ORDERBY._serialized_end=3710
  _LISTJOBSREQUEST_PAGINATION._serialized_start=3713
  _LISTJOBSREQUEST_PAGINATION._serialized_end=3983
  _LISTJOBSREQUEST_PAGINATION_MEMENTO._serialized_start=3839
  _LISTJOBSREQUEST_PAGINATION_MEMENTO._serialized_end=3983
  _LISTJOBSREQUEST_FILTERING._serialized_start=3986
  _LISTJOBSREQUEST_FILTERING._serialized_end=4723
  _LISTJOBSREQUEST_FILTERING_IMAGEFILTER._serialized_start=4640
  _LISTJOBSREQUEST_FILTERING_IMAGEFILTER._serialized_end=4723
  _LISTJOBSRESPONSE._serialized_start=4732
  _LISTJOBSRESPONSE._serialized_end=4982
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_start=4908
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_end=4976
  _LISTWORKFLOWSREQUEST._serialized_start=4985
  _LISTWORKFLOWSREQUEST._serialized_end=6013
  _LISTWORKFLOWSREQUEST_ORDER._serialized_start=5214
  _LISTWORKFLOWSREQUEST_ORDER._serialized_end=5390
  _LISTWORKFLOWSREQUEST_ORDER_ORDERBY._serialized_start=5325
  _LISTWORKFLOWSREQUEST_ORDER_ORDERBY._serialized_end=5390
  _LISTWORKFLOWSREQUEST_PAGINATION._serialized_start=5393
  _LISTWORKFLOWSREQUEST_PAGINATION._serialized_end=5608
  _LISTWORKFLOWSREQUEST_PAGINATION_MEMENTO._serialized_start=5523
  _LISTWORKFLOWSREQUEST_PAGINATION_MEMENTO._serialized_end=5608
  _LISTWORKFLOWSREQUEST_FILTERING._serialized_start=5611
  _LISTWORKFLOWSREQUEST_FILTERING._serialized_end=6007
  _LISTWORKFLOWSRESPONSE._serialized_start=6016
  _LISTWORKFLOWSRESPONSE._serialized_end=6286
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_start=4908
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_end=4976
  _SUBMITREQUEST._serialized_start=6289
  _SUBMITREQUEST._serialized_end=6583
  _SUBMITRESPONSE._serialized_start=6586
  _SUBMITRESPONSE._serialized_end=6822
  _SUBMITRESPONSE_SUGGESTEDPARAMETERS._serialized_start=6702
  _SUBMITRESPONSE_SUGGESTEDPARAMETERS._serialized_end=6814
  _STREAMREQUEST._serialized_start=6824
  _STREAMREQUEST._serialized_end=6898
  _STREAMRESPONSE._serialized_start=6900
  _STREAMRESPONSE._serialized_end=6953
  _GETLOGSREQUEST._serialized_start=6955
  _GETLOGSREQUEST._serialized_end=7041
  _CANCELREQUEST._serialized_start=7043
  _CANCELREQUEST._serialized_end=7095
  _CANCELRESPONSE._serialized_start=7097
  _CANCELRESPONSE._serialized_end=7113
  _DELETEREQUEST._serialized_start=7115
  _DELETEREQUEST._serialized_end=7167
  _DELETERESPONSE._serialized_start=7169
  _DELETERESPONSE._serialized_end=7185
  _DELETEWORKFLOWREQUEST._serialized_start=7187
  _DELETEWORKFLOWREQUEST._serialized_end=7252
  _DELETEWORKFLOWRESPONSE._serialized_start=7254
  _DELETEWORKFLOWRESPONSE._serialized_end=7299
  _JOBEVENT._serialized_start=7302
  _JOBEVENT._serialized_end=7809
  _JOBEVENT_RETURNVALUE._serialized_start=7510
  _JOBEVENT_RETURNVALUE._serialized_end=7801
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_start=7716
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_end=7801
  _JOBSTATEMESSAGE._serialized_start=7811
  _JOBSTATEMESSAGE._serialized_end=7914
  _JOBSERVICE._serialized_start=8200
  _JOBSERVICE._serialized_end=9605
# @@protoc_insertion_point(module_scope)
