# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import alert_pb2 as alert__pb2


class AlertServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DismissAlert = channel.unary_unary(
                '/batchx.alert.AlertService/DismissAlert',
                request_serializer=alert__pb2.DismissAlertRequest.SerializeToString,
                response_deserializer=alert__pb2.DismissAlertResponse.FromString,
                )
        self.DismissAllAlerts = channel.unary_unary(
                '/batchx.alert.AlertService/DismissAllAlerts',
                request_serializer=alert__pb2.DismissAllAlertsRequest.SerializeToString,
                response_deserializer=alert__pb2.DismissAllAlertsResponse.FromString,
                )
        self.ListAlerts = channel.unary_unary(
                '/batchx.alert.AlertService/ListAlerts',
                request_serializer=alert__pb2.ListAlertsRequest.SerializeToString,
                response_deserializer=alert__pb2.ListAlertsResponse.FromString,
                )


class AlertServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DismissAlert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DismissAllAlerts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAlerts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DismissAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.DismissAlert,
                    request_deserializer=alert__pb2.DismissAlertRequest.FromString,
                    response_serializer=alert__pb2.DismissAlertResponse.SerializeToString,
            ),
            'DismissAllAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.DismissAllAlerts,
                    request_deserializer=alert__pb2.DismissAllAlertsRequest.FromString,
                    response_serializer=alert__pb2.DismissAllAlertsResponse.SerializeToString,
            ),
            'ListAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAlerts,
                    request_deserializer=alert__pb2.ListAlertsRequest.FromString,
                    response_serializer=alert__pb2.ListAlertsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.alert.AlertService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DismissAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/DismissAlert',
            alert__pb2.DismissAlertRequest.SerializeToString,
            alert__pb2.DismissAlertResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DismissAllAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/DismissAllAlerts',
            alert__pb2.DismissAllAlertsRequest.SerializeToString,
            alert__pb2.DismissAllAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/ListAlerts',
            alert__pb2.ListAlertsRequest.SerializeToString,
            alert__pb2.ListAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
