# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import image_pb2 as image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rprofile.proto\x12\x0e\x62\x61tchx.profile\x1a\x0bimage.proto\"\x81\x02\n\x07Profile\x12\x10\n\x08markdown\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0btwitter_url\x18\x03 \x01(\t\x12\x14\n\x0clinkedin_url\x18\x04 \x01(\t\x12\x12\n\ngithub_url\x18\x05 \x01(\t\x12\x39\n\x0cpinned_image\x18\x06 \x03(\x0b\x32#.batchx.profile.Profile.PinnedImage\x1a]\n\x0bPinnedImage\x12\x13\n\tbase_name\x18\x01 \x01(\tH\x00\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x13.batchx.image.ImageH\x00\x42\x13\n\x11RequestOrResponseB\x1f\n\x0fio.batchx.protoB\x0cProfileProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'profile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014ProfileProto'
  _PROFILE._serialized_start=47
  _PROFILE._serialized_end=304
  _PROFILE_PINNEDIMAGE._serialized_start=211
  _PROFILE_PINNEDIMAGE._serialized_end=304
# @@protoc_insertion_point(module_scope)
