# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\rbatchx.common\x1a google/protobuf/descriptor.proto\"\xa4\x01\n\tRateLimit\x12\x14\n\x0cmax_requests\x18\x01 \x01(\x05\x12\x38\n\x0btime_window\x18\x02 \x01(\x0e\x32#.batchx.common.RateLimit.TimeWindow\"G\n\nTimeWindow\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nPER_SECOND\x10\x01\x12\x0e\n\nPER_MINUTE\x10\x02\x12\x0c\n\x08PER_HOUR\x10\x03\"C\n\x07Picture\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\tthumbnail\x18\x02 \x03(\x0b\x32\x18.batchx.common.Thumbnail\"^\n\tThumbnail\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12%\n\x06source\x18\x04 \x01(\x0b\x32\x15.batchx.common.Region\"I\n\x06Region\x12\x0f\n\x07x_start\x18\x01 \x01(\x05\x12\x0f\n\x07y_start\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\"\xa2\x02\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x13\n\x0bts_creation\x18\x03 \x01(\x03\x12\x0e\n\x06public\x18\x04 \x01(\x08\x12\x12\n\nfirst_name\x18\x05 \x01(\t\x12\x11\n\tlast_name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x0f\n\x07\x63ompany\x18\x08 \x01(\t\x12\x10\n\x08location\x18\t \x01(\t\x12\x15\n\x0bpicture_key\x18\n \x01(\tH\x00\x12)\n\x07picture\x18\x0b \x01(\x0b\x32\x16.batchx.common.PictureH\x00\x12\x15\n\rbatchx_member\x18\x0c \x01(\x08\x12\x13\n\x0b\x64istributor\x18\r \x01(\tB\r\n\x0bpictureCase\"\xd6\x03\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bts_creation\x18\x02 \x01(\x03\x12\x0f\n\x07visible\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x15\n\x0bpicture_key\x18\x07 \x01(\tH\x00\x12)\n\x07picture\x18\x08 \x01(\x0b\x32\x16.batchx.common.PictureH\x00\x12\x19\n\x11\x66ounding_provider\x18\t \x01(\x08\x1a\xf2\x01\n\nMembership\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\x12\x0f\n\x07visible\x18\x02 \x01(\x08\x12!\n\x04user\x18\x03 \x01(\x0b\x32\x13.batchx.common.User\x12\x13\n\x0bts_creation\x18\x04 \x01(\x03\"V\n\x0eMembershipType\x12\x0b\n\x07REGULAR\x10\x00\x12\t\n\x05OWNER\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\n\n\x06VIEWER\x10\x03\x12\x0b\n\x07SUPPORT\x10\x04\x12\x08\n\x04NONE\x10\x05\x42\r\n\x0bpictureCase\"*\n\x0eIntRangeFilter\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02to\x18\x02 \x01(\x05\"+\n\x0fLongRangeFilter\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\"?\n\x08PageInfo\x12\x16\n\x0etotal_elements\x18\x01 \x01(\x05\x12\x1b\n\x13\x66irst_element_index\x18\x02 \x01(\x05*<\n\tGpuFamily\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04V100\x10\x01\x12\x07\n\x03K80\x10\x02\x12\x06\n\x02T4\x10\x03\x12\x07\n\x03M60\x10\x04:U\n\x11method_rate_limit\x12\x1e.google.protobuf.MethodOptions\x18\xe0\xd4\x03 \x01(\x0b\x32\x18.batchx.common.RateLimit:B\n\x18method_concurrence_limit\x12\x1e.google.protobuf.MethodOptions\x18\xe1\xd4\x03 \x01(\x05:W\n\x12service_rate_limit\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\xa2\x04 \x01(\x0b\x32\x18.batchx.common.RateLimit:D\n\x19service_concurrence_limit\x12\x1f.google.protobuf.ServiceOptions\x18\xf1\xa2\x04 \x01(\x05\x42\x1e\n\x0fio.batchx.protoB\x0b\x43ommonProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_rate_limit)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_concurrence_limit)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_rate_limit)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_concurrence_limit)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\013CommonProto'
  _GPUFAMILY._serialized_start=1392
  _GPUFAMILY._serialized_end=1452
  _RATELIMIT._serialized_start=66
  _RATELIMIT._serialized_end=230
  _RATELIMIT_TIMEWINDOW._serialized_start=159
  _RATELIMIT_TIMEWINDOW._serialized_end=230
  _PICTURE._serialized_start=232
  _PICTURE._serialized_end=299
  _THUMBNAIL._serialized_start=301
  _THUMBNAIL._serialized_end=395
  _REGION._serialized_start=397
  _REGION._serialized_end=470
  _USER._serialized_start=473
  _USER._serialized_end=763
  _ORGANIZATION._serialized_start=766
  _ORGANIZATION._serialized_end=1236
  _ORGANIZATION_MEMBERSHIP._serialized_start=979
  _ORGANIZATION_MEMBERSHIP._serialized_end=1221
  _ORGANIZATION_MEMBERSHIP_MEMBERSHIPTYPE._serialized_start=1135
  _ORGANIZATION_MEMBERSHIP_MEMBERSHIPTYPE._serialized_end=1221
  _INTRANGEFILTER._serialized_start=1238
  _INTRANGEFILTER._serialized_end=1280
  _LONGRANGEFILTER._serialized_start=1282
  _LONGRANGEFILTER._serialized_end=1325
  _PAGEINFO._serialized_start=1327
  _PAGEINFO._serialized_end=1390
# @@protoc_insertion_point(module_scope)
