# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: organization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import profile_pb2 as profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12organization.proto\x12\x13\x62\x61tchx.organization\x1a\x0c\x63ommon.proto\x1a\rprofile.proto\"\x96\x01\n\nInvitation\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\n\n\x02\x62y\x18\x03 \x01(\t\x12\x43\n\x04type\x18\x04 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\x12\x12\n\ntsCreation\x18\x05 \x01(\x03\"=\n\x17\x44\x65leteMembershipRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteMembershipResponse\">\n\x17\x44\x65leteInvitationRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteInvitationResponse\"=\n\"ListOrganizationInvitationsRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"Z\n#ListOrganizationInvitationsResponse\x12\x33\n\ninvitation\x18\x01 \x03(\x0b\x32\x1f.batchx.organization.Invitation\"\x1c\n\x1aListUserInvitationsRequest\"R\n\x1bListUserInvitationsResponse\x12\x33\n\ninvitation\x18\x01 \x03(\x0b\x32\x1f.batchx.organization.Invitation\"B\n\x17HandleInvitationRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"\x1a\n\x18HandleInvitationResponse\"~\n\x13InviteMemberRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\"\x16\n\x14InviteMemberResponse\"\x9e\x01\n\x19\x43reateOrganizationRequest\x12-\n\x08org_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\x12\x19\n\x11\x63omputing_credits\x18\x03 \x01(\x03\x12\x1b\n\x13\x63redits_environment\x18\x04 \x01(\t\"\x1c\n\x1a\x43reateOrganizationResponse\"G\n\x16GetOrganizationRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x17\n\x0finclude_profile\x18\x02 \x01(\x08\"\xb7\x01\n\x17GetOrganizationResponse\x12\x36\n\x11organization_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12:\n\nmembership\x18\x02 \x03(\x0b\x32&.batchx.common.Organization.Membership\x12(\n\x07profile\x18\x03 \x01(\x0b\x32\x17.batchx.profile.Profile\"x\n\x19UpdateOrganizationRequest\x12\x31\n\x0corganization\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12(\n\x07profile\x18\x02 \x01(\x0b\x32\x17.batchx.profile.Profile\"\x1c\n\x1aUpdateOrganizationResponse2\xf1\x08\n\x13OrganizationService\x12q\n\x0fGetOrganization\x12+.batchx.organization.GetOrganizationRequest\x1a,.batchx.organization.GetOrganizationResponse\"\x03\x90\x02\x01\x12z\n\x12UpdateOrganization\x12..batchx.organization.UpdateOrganizationRequest\x1a/.batchx.organization.UpdateOrganizationResponse\"\x03\x90\x02\x02\x12z\n\x12\x43reateOrganization\x12..batchx.organization.CreateOrganizationRequest\x1a/.batchx.organization.CreateOrganizationResponse\"\x03\x90\x02\x02\x12h\n\x0cInviteMember\x12(.batchx.organization.InviteMemberRequest\x1a).batchx.organization.InviteMemberResponse\"\x03\x90\x02\x02\x12t\n\x10HandleInvitation\x12,.batchx.organization.HandleInvitationRequest\x1a-.batchx.organization.HandleInvitationResponse\"\x03\x90\x02\x02\x12\x95\x01\n\x1bListOrganizationInvitations\x12\x37.batchx.organization.ListOrganizationInvitationsRequest\x1a\x38.batchx.organization.ListOrganizationInvitationsResponse\"\x03\x90\x02\x02\x12}\n\x13ListUserInvitations\x12/.batchx.organization.ListUserInvitationsRequest\x1a\x30.batchx.organization.ListUserInvitationsResponse\"\x03\x90\x02\x02\x12t\n\x10\x44\x65leteInvitation\x12,.batchx.organization.DeleteInvitationRequest\x1a-.batchx.organization.DeleteInvitationResponse\"\x03\x90\x02\x02\x12t\n\x10\x44\x65leteMembership\x12,.batchx.organization.DeleteMembershipRequest\x1a-.batchx.organization.DeleteMembershipResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x05\x82\x97\"\x02\x10\x01\x42\x11\n\x0fio.batchx.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'organization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.proto'
  _ORGANIZATIONSERVICE._options = None
  _ORGANIZATIONSERVICE._serialized_options = b'\202\227\"\002\010\005\202\227\"\002\020\001'
  _ORGANIZATIONSERVICE.methods_by_name['GetOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\220\002\001'
  _ORGANIZATIONSERVICE.methods_by_name['UpdateOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['CreateOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['InviteMember']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['InviteMember']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['HandleInvitation']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['HandleInvitation']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['ListOrganizationInvitations']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListOrganizationInvitations']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['ListUserInvitations']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListUserInvitations']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['DeleteInvitation']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['DeleteInvitation']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['DeleteMembership']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['DeleteMembership']._serialized_options = b'\220\002\002'
  _INVITATION._serialized_start=73
  _INVITATION._serialized_end=223
  _DELETEMEMBERSHIPREQUEST._serialized_start=225
  _DELETEMEMBERSHIPREQUEST._serialized_end=286
  _DELETEMEMBERSHIPRESPONSE._serialized_start=288
  _DELETEMEMBERSHIPRESPONSE._serialized_end=314
  _DELETEINVITATIONREQUEST._serialized_start=316
  _DELETEINVITATIONREQUEST._serialized_end=378
  _DELETEINVITATIONRESPONSE._serialized_start=380
  _DELETEINVITATIONRESPONSE._serialized_end=406
  _LISTORGANIZATIONINVITATIONSREQUEST._serialized_start=408
  _LISTORGANIZATIONINVITATIONSREQUEST._serialized_end=469
  _LISTORGANIZATIONINVITATIONSRESPONSE._serialized_start=471
  _LISTORGANIZATIONINVITATIONSRESPONSE._serialized_end=561
  _LISTUSERINVITATIONSREQUEST._serialized_start=563
  _LISTUSERINVITATIONSREQUEST._serialized_end=591
  _LISTUSERINVITATIONSRESPONSE._serialized_start=593
  _LISTUSERINVITATIONSRESPONSE._serialized_end=675
  _HANDLEINVITATIONREQUEST._serialized_start=677
  _HANDLEINVITATIONREQUEST._serialized_end=743
  _HANDLEINVITATIONRESPONSE._serialized_start=745
  _HANDLEINVITATIONRESPONSE._serialized_end=771
  _INVITEMEMBERREQUEST._serialized_start=773
  _INVITEMEMBERREQUEST._serialized_end=899
  _INVITEMEMBERRESPONSE._serialized_start=901
  _INVITEMEMBERRESPONSE._serialized_end=923
  _CREATEORGANIZATIONREQUEST._serialized_start=926
  _CREATEORGANIZATIONREQUEST._serialized_end=1084
  _CREATEORGANIZATIONRESPONSE._serialized_start=1086
  _CREATEORGANIZATIONRESPONSE._serialized_end=1114
  _GETORGANIZATIONREQUEST._serialized_start=1116
  _GETORGANIZATIONREQUEST._serialized_end=1187
  _GETORGANIZATIONRESPONSE._serialized_start=1190
  _GETORGANIZATIONRESPONSE._serialized_end=1373
  _UPDATEORGANIZATIONREQUEST._serialized_start=1375
  _UPDATEORGANIZATIONREQUEST._serialized_end=1495
  _UPDATEORGANIZATIONRESPONSE._serialized_start=1497
  _UPDATEORGANIZATIONRESPONSE._serialized_end=1525
  _ORGANIZATIONSERVICE._serialized_start=1528
  _ORGANIZATIONSERVICE._serialized_end=2665
# @@protoc_insertion_point(module_scope)
