# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import log_pb2 as log__pb2
from . import tag_pb2 as tag__pb2
from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bimage.proto\x12\x0c\x62\x61tchx.image\x1a\tlog.proto\x1a\ttag.proto\x1a\x0c\x63ommon.proto\"C\n\x1d\x41reImageExamplesClonedRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\"0\n\x1e\x41reImageExamplesClonedResponse\x12\x0e\n\x06\x63loned\x18\x01 \x01(\x08\"\xa2\x01\n\x19\x43loneImageExamplesRequest\x12\x1a\n\x12target_environment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12:\n\x04type\x18\x03 \x01(\x0e\x32,.batchx.image.CloneImageExamplesRequest.Type\"\x1e\n\x04Type\x12\t\n\x05\x43LONE\x10\x00\x12\x0b\n\x07UNCLONE\x10\x01\"\x1c\n\x1a\x43loneImageExamplesResponse\")\n\x18ListImageExamplesRequest\x12\r\n\x05image\x18\x01 \x01(\t\"\xb2\x02\n\x19ListImageExamplesResponse\x12@\n\x07\x65xample\x18\x01 \x03(\x0b\x32/.batchx.image.ListImageExamplesResponse.Example\x1a\xd2\x01\n\x07\x45xample\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nts_sharing\x18\x04 \x01(\x03\x12\r\n\x05vcpus\x18\x05 \x01(\x05\x12\x0e\n\x06memory\x18\x06 \x01(\x05\x12\x0c\n\x04gpus\x18\x07 \x01(\x05\x12,\n\ngpu_family\x18\x08 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x12\n\ninput_json\x18\t \x01(\t\x12\x12\n\ninput_size\x18\n \x01(\x03\"M\n\x19RemoveImageExampleRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x12\n\nts_sharing\x18\x03 \x01(\x03\"i\n\x16SetImageExampleRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\"\x1c\n\x1aRemoveImageExampleResponse\"\x19\n\x17SetImageExampleResponse\"a\n\x19GetPushCredentialsRequest\x12\x19\n\x11image_environment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x15\n\rimage_version\x18\x03 \x01(\t\"N\n\x1aGetPushCredentialsResponse\x12\x14\n\x0c\x64ocker_token\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_coordinates\x18\x02 \x01(\t\"E\n\x12ImportImageRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_coordinates\x18\x02 \x01(\t\"\xfa\x11\n\x13SearchImagesRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12;\n\x05query\x18\x02 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x12\x1c\n\x14include_old_versions\x18\x03 \x01(\x08\x12;\n\x08order_by\x18\x04 \x03(\x0b\x32).batchx.image.SearchImagesRequest.OrderBy\x12@\n\npagination\x18\x05 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Pagination\x12\x36\n\x05\x66\x61\x63\x65t\x18\x06 \x03(\x0b\x32\'.batchx.image.SearchImagesRequest.Facet\x12>\n\thighlight\x18\x07 \x03(\x0b\x32+.batchx.image.SearchImagesRequest.Highlight\x1aG\n\x03\x41nd\x12@\n\nexpression\x18\x01 \x03(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1a\x46\n\x02Or\x12@\n\nexpression\x18\x01 \x03(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1aG\n\x03Not\x12@\n\nexpression\x18\x01 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1a\xdc\x02\n\nStringTerm\x12\x41\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x32.batchx.image.SearchImagesRequest.StringTerm.Field\x12\x0e\n\x04term\x18\x02 \x01(\tH\x00\x12\x10\n\x06prefix\x18\x03 \x01(\tH\x00\x12\x10\n\x06phrase\x18\x04 \x01(\tH\x00\"\xce\x01\n\x05\x46ield\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07VERSION\x10\x03\x12\n\n\x06\x41UTHOR\x10\x04\x12\x0e\n\nCATEGORIES\x10\x05\x12\x08\n\x04TAGS\x10\x06\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x07\x12\x11\n\rDOCUMENTATION\x10\x08\x12\t\n\x05INPUT\x10\t\x12\n\n\x06OUTPUT\x10\n\x12\x08\n\x04TYPE\x10\x0b\x12\x10\n\x0cVERSION_RANK\x10\x0c\x12\x0e\n\nVISIBILITY\x10\r\x12\x07\n\x03SCM\x10\x0e\x42\x06\n\x04Type\x1a\xab\x01\n\x0bNumericTerm\x12\x42\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x33.batchx.image.SearchImagesRequest.NumericTerm.Field\x12-\n\x05range\x18\x02 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\")\n\x05\x46ield\x12\t\n\x05PRICE\x10\x00\x12\x08\n\x04SIZE\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x1a\xc0\x02\n\nExpression\x12\x34\n\x03\x61nd\x18\x01 \x01(\x0b\x32%.batchx.image.SearchImagesRequest.AndH\x00\x12\x32\n\x02or\x18\x02 \x01(\x0b\x32$.batchx.image.SearchImagesRequest.OrH\x00\x12\x34\n\x03not\x18\x03 \x01(\x0b\x32%.batchx.image.SearchImagesRequest.NotH\x00\x12\x43\n\x0bstring_term\x18\x04 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.StringTermH\x00\x12\x45\n\x0cnumeric_term\x18\x05 \x01(\x0b\x32-.batchx.image.SearchImagesRequest.NumericTermH\x00\x42\x06\n\x04Type\x1a\x8c\x01\n\x07OrderBy\x12>\n\x05\x66ield\x18\x01 \x01(\x0e\x32/.batchx.image.SearchImagesRequest.OrderBy.Field\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\"3\n\x05\x46ield\x12\x08\n\x04NAME\x10\x00\x12\t\n\x05PRICE\x10\x01\x12\x08\n\x04SIZE\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x1a)\n\nPagination\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\r\n\x05start\x18\x02 \x01(\x05\x1a\xdf\x02\n\x05\x46\x61\x63\x65t\x12<\n\x05\x66ield\x18\x01 \x01(\x0e\x32-.batchx.image.SearchImagesRequest.Facet.Field\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12:\n\x04sort\x18\x03 \x01(\x0e\x32,.batchx.image.SearchImagesRequest.Facet.Sort\x12.\n\x06\x62ucket\x18\x04 \x03(\x0b\x32\x1e.batchx.common.LongRangeFilter\"\x7f\n\x05\x46ield\x12\x0f\n\x0b\x45NVIRONMENT\x10\x00\x12\n\n\x06\x41UTHOR\x10\x01\x12\x0e\n\nCATEGORIES\x10\x02\x12\x08\n\x04TAGS\x10\x03\x12\x08\n\x04TYPE\x10\x04\x12\x08\n\x04SIZE\x10\x05\x12\t\n\x05PRICE\x10\x06\x12\x10\n\x0cVERSION_RANK\x10\x07\x12\x0e\n\nVISIBILITY\x10\x08\"\x1d\n\x04Sort\x12\t\n\x05\x43OUNT\x10\x00\x12\n\n\x06\x42UCKET\x10\x01\x1a\xb5\x02\n\tHighlight\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.batchx.image.SearchImagesRequest.Highlight.Field\x12\x42\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.batchx.image.SearchImagesRequest.Highlight.Format\x12\x13\n\x0bmax_phrases\x18\x03 \x01(\x05\x12\x0f\n\x07pre_tag\x18\x04 \x01(\t\x12\x10\n\x08post_tag\x18\x05 \x01(\t\"L\n\x05\x46ield\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rDOCUMENTATION\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\x12\t\n\x05INPUT\x10\x03\x12\n\n\x06OUTPUT\x10\x04\"\x1c\n\x06\x46ormat\x12\x08\n\x04HTML\x10\x00\x12\x08\n\x04TEXT\x10\x01\"\xe1\x06\n\x14SearchImagesResponse\x12\"\n\x05image\x18\x01 \x03(\x0b\x32\x13.batchx.image.Image\x12\x0c\n\x04hits\x18\x02 \x01(\x03\x12\x43\n\tuser_data\x18\x03 \x03(\x0b\x32\x30.batchx.image.SearchImagesResponse.UserDataEntry\x12\x41\n\x08org_data\x18\x04 \x03(\x0b\x32/.batchx.image.SearchImagesResponse.OrgDataEntry\x12\x44\n\x0c\x66\x61\x63\x65t_result\x18\x05 \x03(\x0b\x32..batchx.image.SearchImagesResponse.FacetResult\x12\x45\n\thighlight\x18\x06 \x03(\x0b\x32\x32.batchx.image.SearchImagesResponse.HighlightResult\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\x1aK\n\x0cOrgDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.batchx.common.Organization:\x02\x38\x01\x1a\xb7\x01\n\x0b\x46\x61\x63\x65tResult\x12<\n\x05\x66ield\x18\x01 \x01(\x0e\x32-.batchx.image.SearchImagesRequest.Facet.Field\x12\x43\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\x34.batchx.image.SearchImagesResponse.FacetResult.Entry\x1a%\n\x05\x45ntry\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x1a\xb4\x01\n\x0fHighlightResult\x12G\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x38.batchx.image.SearchImagesResponse.HighlightResult.Entry\x1aX\n\x05\x45ntry\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.batchx.image.SearchImagesRequest.Highlight.Field\x12\r\n\x05value\x18\x02 \x01(\t\"\xfb\x07\n\x11ListImagesRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x18\n\x10user_environment\x18\x02 \x01(\t\x12<\n\tfiltering\x18\x03 \x01(\x0b\x32).batchx.image.ListImagesRequest.Filtering\x12>\n\npagination\x18\x04 \x01(\x0b\x32*.batchx.image.ListImagesRequest.Pagination\x12\x34\n\x05order\x18\x05 \x01(\x0b\x32%.batchx.image.ListImagesRequest.Order\x12\x18\n\x10only_coordinates\x18\x06 \x01(\x08\x12\x18\n\x10include_manifest\x18\x07 \x01(\x08\x1a\xd4\x02\n\tFiltering\x12\'\n\x03tag\x18\x02 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x19\n\x11image_environment\x18\x03 \x03(\t\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x42\n\x07\x65xclude\x18\x05 \x01(\x0e\x32\x31.batchx.image.ListImagesRequest.Filtering.Exclude\x12\x31\n\tts_import\x18\x07 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12,\n\x04size\x18\t \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x15\n\ronly_featured\x18\n \x01(\x08\"-\n\x07\x45xclude\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOOLS\x10\x01\x12\r\n\tPIPELINES\x10\x02J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\t\x1a\xd4\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x43\n\x07memento\x18\x02 \x01(\x0b\x32\x32.batchx.image.ListImagesRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1aS\n\x07Memento\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tts_import\x18\x04 \x01(\x03\x12\x0c\n\x04size\x18\x05 \x01(\x03J\x04\x08\x03\x10\x04\x1a\xa0\x01\n\x05Order\x12?\n\x08order_by\x18\x01 \x01(\x0e\x32-.batchx.image.ListImagesRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"2\n\x07OrderBy\x12\r\n\tTS_IMPORT\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04SIZE\x10\x03\"\x04\x08\x02\x10\x02\"\x8e\x03\n\x12ListImagesResponse\x12\"\n\x05image\x18\x01 \x03(\x0b\x32\x13.batchx.image.Image\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x41\n\tuser_data\x18\x03 \x03(\x0b\x32..batchx.image.ListImagesResponse.UserDataEntry\x12*\n\tpage_info\x18\x04 \x01(\x0b\x32\x17.batchx.common.PageInfo\x12?\n\x08org_data\x18\x05 \x03(\x0b\x32-.batchx.image.ListImagesResponse.OrgDataEntry\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\x1aK\n\x0cOrgDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.batchx.common.Organization:\x02\x38\x01\"Z\n\x0fTagImageRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12(\n\x04tags\x18\x02 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x03 \x01(\x08\"\x12\n\x10TagImageResponse\" \n\x0fGetImageRequest\x12\r\n\x05image\x18\x01 \x01(\t\"\xd6\x01\n\x11ShareImageRequest\x12\x17\n\x0fimage_base_name\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.batchx.image.ShareImageRequest.Type\x12\x1a\n\x12target_environment\x18\x03 \x01(\t\x12\x32\n\x07pricing\x18\x05 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\"\x1e\n\x04Type\x12\t\n\x05SHARE\x10\x00\x12\x0b\n\x07UNSHARE\x10\x01J\x04\x08\x04\x10\x05\"\x9c\x01\n\x11\x43loneImageRequest\x12\x17\n\x0fimage_base_name\x18\x01 \x01(\t\x12\x1a\n\x12target_environment\x18\x02 \x01(\t\x12\x32\n\x04type\x18\x03 \x01(\x0e\x32$.batchx.image.CloneImageRequest.Type\"\x1e\n\x04Type\x12\t\n\x05\x43LONE\x10\x00\x12\x0b\n\x07UNCLONE\x10\x01\"\x14\n\x12\x43loneImageResponse\"\x14\n\x12ShareImageResponse\"K\n\x10GetImageResponse\x12\"\n\x05image\x18\x01 \x01(\x0b\x32\x13.batchx.image.Image\x12\x13\n\x0bmember_view\x18\x02 \x01(\x08\"=\n\x12\x44\x65leteImageRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\"\xa3\n\n\x05Image\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x18\n\x10manifest_version\x18\x05 \x01(\t\x12\x10\n\x08manifest\x18\x06 \x01(\t\x12\x1d\n\x15platform_architecture\x18\x07 \x01(\t\x12\x13\n\x0bplatform_os\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x32\n\nvisibility\x18\n \x01(\x0e\x32\x1e.batchx.image.Image.Visibility\x12\x11\n\tts_import\x18\x0b \x01(\x03\x12\n\n\x02\x62y\x18\x0c \x01(\t\x12\x0b\n\x03scm\x18\r \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12\x1c\n\x03tag\x18\x0f \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x10\n\x08versions\x18\x11 \x03(\t\x12(\n\x05share\x18\x12 \x03(\x0b\x32\x19.batchx.image.Image.Share\x12\x1a\n\x12\x63loning_envs_count\x18\x13 \x01(\x05\x12(\n\x05\x63lone\x18\x14 \x03(\x0b\x32\x19.batchx.image.Image.Share\x12\'\n\x07picture\x18\x15 \x01(\x0b\x32\x16.batchx.common.Picture\x12\x1c\n\x14pipeline_steps_count\x18\x16 \x01(\x05\x12\x35\n\x0cimage_status\x18\x17 \x01(\x0e\x32\x1f.batchx.image.Image.ImageStatus\x12\x10\n\x08\x66\x65\x61tured\x18\x18 \x01(\x08\x12\x32\n\x07pricing\x18\x19 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x1a\xa8\x04\n\x05Share\x12\x13\n\x0b\x65nvironment\x18\x03 \x01(\t\x12\'\n\x07picture\x18\x05 \x01(\x0b\x32\x16.batchx.common.Picture\x12,\n\x04type\x18\x06 \x01(\x0e\x32\x1e.batchx.image.Image.Share.Type\x12\x32\n\x07pricing\x18\x07 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x1a\xd4\x02\n\x07Pricing\x12\x15\n\x0b\x66ixed_price\x18\x01 \x01(\x03H\x00\x12L\n\x0fper_mline_price\x18\x04 \x01(\x0b\x32\x31.batchx.image.Image.Share.Pricing.PerMlinePricingH\x00\x12L\n\x0fper_mbyte_price\x18\x05 \x01(\x0b\x32\x31.batchx.image.Image.Share.Pricing.PerMbytePricingH\x00\x1a@\n\x0fPerMlinePricing\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x13\n\x0bmline_price\x18\x03 \x01(\x03\x1a@\n\x0fPerMbytePricing\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x13\n\x0bmbyte_price\x18\x03 \x01(\x03\x42\x06\n\x04\x43\x61seJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\"\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x10\n\x0cORGANIZATION\x10\x01J\x04\x08\x04\x10\x05\")\n\nVisibility\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04SOME\x10\x02\"3\n\x0bImageStatus\x12\x0c\n\x08IMPORTED\x10\x00\x12\n\n\x06SHARED\x10\x01\x12\n\n\x06\x43LONED\x10\x02J\x04\x08\x10\x10\x11*9\n\x0cVERSION_RANK\x12\t\n\x05STALE\x10\x00\x12\x0b\n\x07HIGHEST\x10\x01\x12\x11\n\rHIGHEST_MAJOR\x10\x02\x32\xfd\n\n\x0cImageService\x12N\n\x0bImportImage\x12 .batchx.image.ImportImageRequest\x1a\x15.batchx.log.LogRecord\"\x04\x88\xa6\x1d\x01\x30\x01\x12x\n\x12GetPushCredentials\x12\'.batchx.image.GetPushCredentialsRequest\x1a(.batchx.image.GetPushCredentialsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12`\n\nListImages\x12\x1f.batchx.image.ListImagesRequest\x1a .batchx.image.ListImagesResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12\x66\n\x0cSearchImages\x12!.batchx.image.SearchImagesRequest\x1a\".batchx.image.SearchImagesResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12N\n\x08GetImage\x12\x1d.batchx.image.GetImageRequest\x1a\x1e.batchx.image.GetImageResponse\"\x03\x90\x02\x01\x12T\n\nShareImage\x12\x1f.batchx.image.ShareImageRequest\x1a .batchx.image.ShareImageResponse\"\x03\x90\x02\x02\x12T\n\nCloneImage\x12\x1f.batchx.image.CloneImageRequest\x1a .batchx.image.CloneImageResponse\"\x03\x90\x02\x02\x12Y\n\x0b\x44\x65leteImage\x12 .batchx.image.DeleteImageRequest\x1a\x15.batchx.log.LogRecord\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x05\x82\xa6\x1d\x02\x10\x02\x30\x01\x12N\n\x08TagImage\x12\x1d.batchx.image.TagImageRequest\x1a\x1e.batchx.image.TagImageResponse\"\x03\x90\x02\x02\x12x\n\x16\x41reImageExamplesCloned\x12+.batchx.image.AreImageExamplesClonedRequest\x1a,.batchx.image.AreImageExamplesClonedResponse\"\x03\x90\x02\x02\x12l\n\x12\x43loneImageExamples\x12\'.batchx.image.CloneImageExamplesRequest\x1a(.batchx.image.CloneImageExamplesResponse\"\x03\x90\x02\x02\x12i\n\x11ListImageExamples\x12&.batchx.image.ListImageExamplesRequest\x1a\'.batchx.image.ListImageExamplesResponse\"\x03\x90\x02\x02\x12\x63\n\x0fSetImageExample\x12$.batchx.image.SetImageExampleRequest\x1a%.batchx.image.SetImageExampleResponse\"\x03\x90\x02\x02\x12l\n\x12RemoveImageExample\x12\'.batchx.image.RemoveImageExampleRequest\x1a(.batchx.image.RemoveImageExampleResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1d\n\x0fio.batchx.protoB\nImageProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nImageProto'
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._options = None
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._options = None
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_options = b'8\001'
  _LISTIMAGESRESPONSE_USERDATAENTRY._options = None
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _LISTIMAGESRESPONSE_ORGDATAENTRY._options = None
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_options = b'8\001'
  _IMAGESERVICE._options = None
  _IMAGESERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _IMAGESERVICE.methods_by_name['ImportImage']._options = None
  _IMAGESERVICE.methods_by_name['ImportImage']._serialized_options = b'\210\246\035\001'
  _IMAGESERVICE.methods_by_name['GetPushCredentials']._options = None
  _IMAGESERVICE.methods_by_name['GetPushCredentials']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['ListImages']._options = None
  _IMAGESERVICE.methods_by_name['ListImages']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['SearchImages']._options = None
  _IMAGESERVICE.methods_by_name['SearchImages']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['GetImage']._options = None
  _IMAGESERVICE.methods_by_name['GetImage']._serialized_options = b'\220\002\001'
  _IMAGESERVICE.methods_by_name['ShareImage']._options = None
  _IMAGESERVICE.methods_by_name['ShareImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['CloneImage']._options = None
  _IMAGESERVICE.methods_by_name['CloneImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['DeleteImage']._options = None
  _IMAGESERVICE.methods_by_name['DeleteImage']._serialized_options = b'\220\002\002\202\246\035\002\010\005\202\246\035\002\020\002'
  _IMAGESERVICE.methods_by_name['TagImage']._options = None
  _IMAGESERVICE.methods_by_name['TagImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['AreImageExamplesCloned']._options = None
  _IMAGESERVICE.methods_by_name['AreImageExamplesCloned']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['CloneImageExamples']._options = None
  _IMAGESERVICE.methods_by_name['CloneImageExamples']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['ListImageExamples']._options = None
  _IMAGESERVICE.methods_by_name['ListImageExamples']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['SetImageExample']._options = None
  _IMAGESERVICE.methods_by_name['SetImageExample']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['RemoveImageExample']._options = None
  _IMAGESERVICE.methods_by_name['RemoveImageExample']._serialized_options = b'\220\002\002'
  _VERSION_RANK._serialized_start=7840
  _VERSION_RANK._serialized_end=7897
  _AREIMAGEEXAMPLESCLONEDREQUEST._serialized_start=65
  _AREIMAGEEXAMPLESCLONEDREQUEST._serialized_end=132
  _AREIMAGEEXAMPLESCLONEDRESPONSE._serialized_start=134
  _AREIMAGEEXAMPLESCLONEDRESPONSE._serialized_end=182
  _CLONEIMAGEEXAMPLESREQUEST._serialized_start=185
  _CLONEIMAGEEXAMPLESREQUEST._serialized_end=347
  _CLONEIMAGEEXAMPLESREQUEST_TYPE._serialized_start=317
  _CLONEIMAGEEXAMPLESREQUEST_TYPE._serialized_end=347
  _CLONEIMAGEEXAMPLESRESPONSE._serialized_start=349
  _CLONEIMAGEEXAMPLESRESPONSE._serialized_end=377
  _LISTIMAGEEXAMPLESREQUEST._serialized_start=379
  _LISTIMAGEEXAMPLESREQUEST._serialized_end=420
  _LISTIMAGEEXAMPLESRESPONSE._serialized_start=423
  _LISTIMAGEEXAMPLESRESPONSE._serialized_end=729
  _LISTIMAGEEXAMPLESRESPONSE_EXAMPLE._serialized_start=519
  _LISTIMAGEEXAMPLESRESPONSE_EXAMPLE._serialized_end=729
  _REMOVEIMAGEEXAMPLEREQUEST._serialized_start=731
  _REMOVEIMAGEEXAMPLEREQUEST._serialized_end=808
  _SETIMAGEEXAMPLEREQUEST._serialized_start=810
  _SETIMAGEEXAMPLEREQUEST._serialized_end=915
  _REMOVEIMAGEEXAMPLERESPONSE._serialized_start=917
  _REMOVEIMAGEEXAMPLERESPONSE._serialized_end=945
  _SETIMAGEEXAMPLERESPONSE._serialized_start=947
  _SETIMAGEEXAMPLERESPONSE._serialized_end=972
  _GETPUSHCREDENTIALSREQUEST._serialized_start=974
  _GETPUSHCREDENTIALSREQUEST._serialized_end=1071
  _GETPUSHCREDENTIALSRESPONSE._serialized_start=1073
  _GETPUSHCREDENTIALSRESPONSE._serialized_end=1151
  _IMPORTIMAGEREQUEST._serialized_start=1153
  _IMPORTIMAGEREQUEST._serialized_end=1222
  _SEARCHIMAGESREQUEST._serialized_start=1225
  _SEARCHIMAGESREQUEST._serialized_end=3523
  _SEARCHIMAGESREQUEST_AND._serialized_start=1607
  _SEARCHIMAGESREQUEST_AND._serialized_end=1678
  _SEARCHIMAGESREQUEST_OR._serialized_start=1680
  _SEARCHIMAGESREQUEST_OR._serialized_end=1750
  _SEARCHIMAGESREQUEST_NOT._serialized_start=1752
  _SEARCHIMAGESREQUEST_NOT._serialized_end=1823
  _SEARCHIMAGESREQUEST_STRINGTERM._serialized_start=1826
  _SEARCHIMAGESREQUEST_STRINGTERM._serialized_end=2174
  _SEARCHIMAGESREQUEST_STRINGTERM_FIELD._serialized_start=1960
  _SEARCHIMAGESREQUEST_STRINGTERM_FIELD._serialized_end=2166
  _SEARCHIMAGESREQUEST_NUMERICTERM._serialized_start=2177
  _SEARCHIMAGESREQUEST_NUMERICTERM._serialized_end=2348
  _SEARCHIMAGESREQUEST_NUMERICTERM_FIELD._serialized_start=2307
  _SEARCHIMAGESREQUEST_NUMERICTERM_FIELD._serialized_end=2348
  _SEARCHIMAGESREQUEST_EXPRESSION._serialized_start=2351
  _SEARCHIMAGESREQUEST_EXPRESSION._serialized_end=2671
  _SEARCHIMAGESREQUEST_ORDERBY._serialized_start=2674
  _SEARCHIMAGESREQUEST_ORDERBY._serialized_end=2814
  _SEARCHIMAGESREQUEST_ORDERBY_FIELD._serialized_start=2763
  _SEARCHIMAGESREQUEST_ORDERBY_FIELD._serialized_end=2814
  _SEARCHIMAGESREQUEST_PAGINATION._serialized_start=2816
  _SEARCHIMAGESREQUEST_PAGINATION._serialized_end=2857
  _SEARCHIMAGESREQUEST_FACET._serialized_start=2860
  _SEARCHIMAGESREQUEST_FACET._serialized_end=3211
  _SEARCHIMAGESREQUEST_FACET_FIELD._serialized_start=3053
  _SEARCHIMAGESREQUEST_FACET_FIELD._serialized_end=3180
  _SEARCHIMAGESREQUEST_FACET_SORT._serialized_start=3182
  _SEARCHIMAGESREQUEST_FACET_SORT._serialized_end=3211
  _SEARCHIMAGESREQUEST_HIGHLIGHT._serialized_start=3214
  _SEARCHIMAGESREQUEST_HIGHLIGHT._serialized_end=3523
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FIELD._serialized_start=3417
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FIELD._serialized_end=3493
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FORMAT._serialized_start=3495
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FORMAT._serialized_end=3523
  _SEARCHIMAGESRESPONSE._serialized_start=3526
  _SEARCHIMAGESRESPONSE._serialized_end=4391
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_start=3877
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_end=3945
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_start=3947
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_end=4022
  _SEARCHIMAGESRESPONSE_FACETRESULT._serialized_start=4025
  _SEARCHIMAGESRESPONSE_FACETRESULT._serialized_end=4208
  _SEARCHIMAGESRESPONSE_FACETRESULT_ENTRY._serialized_start=4171
  _SEARCHIMAGESRESPONSE_FACETRESULT_ENTRY._serialized_end=4208
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT._serialized_start=4211
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT._serialized_end=4391
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT_ENTRY._serialized_start=4303
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT_ENTRY._serialized_end=4391
  _LISTIMAGESREQUEST._serialized_start=4394
  _LISTIMAGESREQUEST._serialized_end=5413
  _LISTIMAGESREQUEST_FILTERING._serialized_start=4695
  _LISTIMAGESREQUEST_FILTERING._serialized_end=5035
  _LISTIMAGESREQUEST_FILTERING_EXCLUDE._serialized_start=4978
  _LISTIMAGESREQUEST_FILTERING_EXCLUDE._serialized_end=5023
  _LISTIMAGESREQUEST_PAGINATION._serialized_start=5038
  _LISTIMAGESREQUEST_PAGINATION._serialized_end=5250
  _LISTIMAGESREQUEST_PAGINATION_MEMENTO._serialized_start=5167
  _LISTIMAGESREQUEST_PAGINATION_MEMENTO._serialized_end=5250
  _LISTIMAGESREQUEST_ORDER._serialized_start=5253
  _LISTIMAGESREQUEST_ORDER._serialized_end=5413
  _LISTIMAGESREQUEST_ORDER_ORDERBY._serialized_start=5363
  _LISTIMAGESREQUEST_ORDER_ORDERBY._serialized_end=5413
  _LISTIMAGESRESPONSE._serialized_start=5416
  _LISTIMAGESRESPONSE._serialized_end=5814
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_start=3877
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_end=3945
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_start=3947
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_end=4022
  _TAGIMAGEREQUEST._serialized_start=5816
  _TAGIMAGEREQUEST._serialized_end=5906
  _TAGIMAGERESPONSE._serialized_start=5908
  _TAGIMAGERESPONSE._serialized_end=5926
  _GETIMAGEREQUEST._serialized_start=5928
  _GETIMAGEREQUEST._serialized_end=5960
  _SHAREIMAGEREQUEST._serialized_start=5963
  _SHAREIMAGEREQUEST._serialized_end=6177
  _SHAREIMAGEREQUEST_TYPE._serialized_start=6141
  _SHAREIMAGEREQUEST_TYPE._serialized_end=6171
  _CLONEIMAGEREQUEST._serialized_start=6180
  _CLONEIMAGEREQUEST._serialized_end=6336
  _CLONEIMAGEREQUEST_TYPE._serialized_start=317
  _CLONEIMAGEREQUEST_TYPE._serialized_end=347
  _CLONEIMAGERESPONSE._serialized_start=6338
  _CLONEIMAGERESPONSE._serialized_end=6358
  _SHAREIMAGERESPONSE._serialized_start=6360
  _SHAREIMAGERESPONSE._serialized_end=6380
  _GETIMAGERESPONSE._serialized_start=6382
  _GETIMAGERESPONSE._serialized_end=6457
  _DELETEIMAGEREQUEST._serialized_start=6459
  _DELETEIMAGEREQUEST._serialized_end=6520
  _IMAGE._serialized_start=6523
  _IMAGE._serialized_end=7838
  _IMAGE_SHARE._serialized_start=7184
  _IMAGE_SHARE._serialized_end=7736
  _IMAGE_SHARE_PRICING._serialized_start=7354
  _IMAGE_SHARE_PRICING._serialized_end=7694
  _IMAGE_SHARE_PRICING_PERMLINEPRICING._serialized_start=7544
  _IMAGE_SHARE_PRICING_PERMLINEPRICING._serialized_end=7608
  _IMAGE_SHARE_PRICING_PERMBYTEPRICING._serialized_start=7610
  _IMAGE_SHARE_PRICING_PERMBYTEPRICING._serialized_end=7674
  _IMAGE_SHARE_TYPE._serialized_start=7696
  _IMAGE_SHARE_TYPE._serialized_end=7730
  _IMAGE_VISIBILITY._serialized_start=7738
  _IMAGE_VISIBILITY._serialized_end=7779
  _IMAGE_IMAGESTATUS._serialized_start=7781
  _IMAGE_IMAGESTATUS._serialized_end=7832
  _IMAGESERVICE._serialized_start=7900
  _IMAGESERVICE._serialized_end=9305
# @@protoc_insertion_point(module_scope)
