# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: consumer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63onsumer.proto\x12\x0f\x62\x61tchx.consumer\x1a\x0c\x63ommon.proto\"Y\n\x11GetMetricsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07ts_from\x18\x02 \x01(\x03\x12\r\n\x05ts_to\x18\x03 \x01(\x03\x12\x0f\n\x07\x62uckets\x18\x04 \x01(\x05\"\xb2\x03\n\x12GetMetricsResponse\x12L\n\x0e\x62ucket_metrics\x18\x01 \x03(\x0b\x32\x34.batchx.consumer.GetMetricsResponse.JobBucketMetrics\x12\x43\n\x0bjob_metrics\x18\x02 \x01(\x0b\x32..batchx.consumer.GetMetricsResponse.JobMetrics\x1a\x66\n\x10JobBucketMetrics\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x05\x12\x12\n\nnon_cached\x18\x02 \x01(\x05\x12\x12\n\nimage_fees\x18\x03 \x01(\x03\x12\x19\n\x11\x63omputation_costs\x18\x04 \x01(\x03\x1a\xa0\x01\n\nJobMetrics\x12[\n\x0fstatus_counters\x18\x01 \x03(\x0b\x32\x42.batchx.consumer.GetMetricsResponse.JobMetrics.StatusCountersEntry\x1a\x35\n\x13StatusCountersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x32{\n\x0f\x43onsumerService\x12Z\n\nGetMetrics\x12\".batchx.consumer.GetMetricsRequest\x1a#.batchx.consumer.GetMetricsResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42 \n\x0fio.batchx.protoB\rConsumerProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'consumer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\rConsumerProto'
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._options = None
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_options = b'8\001'
  _CONSUMERSERVICE._options = None
  _CONSUMERSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _CONSUMERSERVICE.methods_by_name['GetMetrics']._options = None
  _CONSUMERSERVICE.methods_by_name['GetMetrics']._serialized_options = b'\220\002\001'
  _GETMETRICSREQUEST._serialized_start=49
  _GETMETRICSREQUEST._serialized_end=138
  _GETMETRICSRESPONSE._serialized_start=141
  _GETMETRICSRESPONSE._serialized_end=575
  _GETMETRICSRESPONSE_JOBBUCKETMETRICS._serialized_start=310
  _GETMETRICSRESPONSE_JOBBUCKETMETRICS._serialized_end=412
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_start=415
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_end=575
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_start=522
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_end=575
  _CONSUMERSERVICE._serialized_start=577
  _CONSUMERSERVICE._serialized_end=700
# @@protoc_insertion_point(module_scope)
